/*******************************************************************************

    uBlock Origin Lite - a comprehensive, MV3-compliant content blocker
    Copyright (C) 2014-present Raymond Hill

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see {http://www.gnu.org/licenses/}.

    Home: https://github.com/gorhill/uBlock

*/

// ruleset: ublock-filters

// Important!
// Isolate from global scope

// Start of local scope
(function uBOL_abortCurrentScript() {

/******************************************************************************/

function abortCurrentScript(...args) {
    runAtHtmlElementFn(( ) => {
        abortCurrentScriptCore(...args);
    });
}

function abortCurrentScriptCore(
    target = '',
    needle = '',
    context = ''
) {
    if ( typeof target !== 'string' ) { return; }
    if ( target === '' ) { return; }
    const safe = safeSelf();
    const logPrefix = safe.makeLogPrefix('abort-current-script', target, needle, context);
    const reNeedle = safe.patternToRegex(needle);
    const reContext = safe.patternToRegex(context);
    const extraArgs = safe.getExtraArgs(Array.from(arguments), 3);
    const thisScript = document.currentScript;
    const chain = safe.String_split.call(target, '.');
    let owner = window;
    let prop;
    for (;;) {
        prop = chain.shift();
        if ( chain.length === 0 ) { break; }
        if ( prop in owner === false ) { break; }
        owner = owner[prop];
        if ( owner instanceof Object === false ) { return; }
    }
    let value;
    let desc = Object.getOwnPropertyDescriptor(owner, prop);
    if (
        desc instanceof Object === false ||
        desc.get instanceof Function === false
    ) {
        value = owner[prop];
        desc = undefined;
    }
    const debug = shouldDebug(extraArgs);
    const exceptionToken = getExceptionTokenFn();
    const scriptTexts = new WeakMap();
    const getScriptText = elem => {
        let text = elem.textContent;
        if ( text.trim() !== '' ) { return text; }
        if ( scriptTexts.has(elem) ) { return scriptTexts.get(elem); }
        const [ , mime, content ] =
            /^data:([^,]*),(.+)$/.exec(elem.src.trim()) ||
            [ '', '', '' ];
        try {
            switch ( true ) {
            case mime.endsWith(';base64'):
                text = self.atob(content);
                break;
            default:
                text = self.decodeURIComponent(content);
                break;
            }
        } catch {
        }
        scriptTexts.set(elem, text);
        return text;
    };
    const validate = ( ) => {
        const e = document.currentScript;
        if ( e instanceof HTMLScriptElement === false ) { return; }
        if ( e === thisScript ) { return; }
        if ( context !== '' && reContext.test(e.src) === false ) {
            // eslint-disable-next-line no-debugger
            if ( debug === 'nomatch' || debug === 'all' ) { debugger; }
            return;
        }
        if ( safe.logLevel > 1 && context !== '' ) {
            safe.uboLog(logPrefix, `Matched src\n${e.src}`);
        }
        const scriptText = getScriptText(e);
        if ( reNeedle.test(scriptText) === false ) {
            // eslint-disable-next-line no-debugger
            if ( debug === 'nomatch' || debug === 'all' ) { debugger; }
            return;
        }
        if ( safe.logLevel > 1 ) {
            safe.uboLog(logPrefix, `Matched text\n${scriptText}`);
        }
        // eslint-disable-next-line no-debugger
        if ( debug === 'match' || debug === 'all' ) { debugger; }
        safe.uboLog(logPrefix, 'Aborted');
        throw new ReferenceError(exceptionToken);
    };
    // eslint-disable-next-line no-debugger
    if ( debug === 'install' ) { debugger; }
    try {
        Object.defineProperty(owner, prop, {
            get: function() {
                validate();
                return desc instanceof Object
                    ? desc.get.call(owner)
                    : value;
            },
            set: function(a) {
                validate();
                if ( desc instanceof Object ) {
                    desc.set.call(owner, a);
                } else {
                    value = a;
                }
            }
        });
    } catch(ex) {
        safe.uboErr(logPrefix, `Error: ${ex}`);
    }
}

function runAtHtmlElementFn(fn) {
    if ( document.documentElement ) {
        fn();
        return;
    }
    const observer = new MutationObserver(( ) => {
        observer.disconnect();
        fn();
    });
    observer.observe(document, { childList: true });
}

function getExceptionTokenFn() {
    const token = getRandomTokenFn();
    const oe = self.onerror;
    self.onerror = function(msg, ...args) {
        if ( typeof msg === 'string' && msg.includes(token) ) { return true; }
        if ( oe instanceof Function ) {
            return oe.call(this, msg, ...args);
        }
    }.bind();
    return token;
}

function safeSelf() {
    if ( scriptletGlobals.safeSelf ) {
        return scriptletGlobals.safeSelf;
    }
    const self = globalThis;
    const safe = {
        'Array_from': Array.from,
        'Error': self.Error,
        'Function_toStringFn': self.Function.prototype.toString,
        'Function_toString': thisArg => safe.Function_toStringFn.call(thisArg),
        'Math_floor': Math.floor,
        'Math_max': Math.max,
        'Math_min': Math.min,
        'Math_random': Math.random,
        'Object': Object,
        'Object_defineProperty': Object.defineProperty.bind(Object),
        'Object_defineProperties': Object.defineProperties.bind(Object),
        'Object_fromEntries': Object.fromEntries.bind(Object),
        'Object_getOwnPropertyDescriptor': Object.getOwnPropertyDescriptor.bind(Object),
        'Object_hasOwn': Object.hasOwn.bind(Object),
        'RegExp': self.RegExp,
        'RegExp_test': self.RegExp.prototype.test,
        'RegExp_exec': self.RegExp.prototype.exec,
        'Request_clone': self.Request.prototype.clone,
        'String': self.String,
        'String_fromCharCode': String.fromCharCode,
        'String_split': String.prototype.split,
        'XMLHttpRequest': self.XMLHttpRequest,
        'addEventListener': self.EventTarget.prototype.addEventListener,
        'removeEventListener': self.EventTarget.prototype.removeEventListener,
        'fetch': self.fetch,
        'JSON': self.JSON,
        'JSON_parseFn': self.JSON.parse,
        'JSON_stringifyFn': self.JSON.stringify,
        'JSON_parse': (...args) => safe.JSON_parseFn.call(safe.JSON, ...args),
        'JSON_stringify': (...args) => safe.JSON_stringifyFn.call(safe.JSON, ...args),
        'log': console.log.bind(console),
        // Properties
        logLevel: 0,
        // Methods
        makeLogPrefix(...args) {
            return this.sendToLogger && `[${args.join(' \u205D ')}]` || '';
        },
        uboLog(...args) {
            if ( this.sendToLogger === undefined ) { return; }
            if ( args === undefined || args[0] === '' ) { return; }
            return this.sendToLogger('info', ...args);
            
        },
        uboErr(...args) {
            if ( this.sendToLogger === undefined ) { return; }
            if ( args === undefined || args[0] === '' ) { return; }
            return this.sendToLogger('error', ...args);
        },
        escapeRegexChars(s) {
            return s.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
        },
        initPattern(pattern, options = {}) {
            if ( pattern === '' ) {
                return { matchAll: true, expect: true };
            }
            const expect = (options.canNegate !== true || pattern.startsWith('!') === false);
            if ( expect === false ) {
                pattern = pattern.slice(1);
            }
            const match = /^\/(.+)\/([gimsu]*)$/.exec(pattern);
            if ( match !== null ) {
                return {
                    re: new this.RegExp(
                        match[1],
                        match[2] || options.flags
                    ),
                    expect,
                };
            }
            if ( options.flags !== undefined ) {
                return {
                    re: new this.RegExp(this.escapeRegexChars(pattern),
                        options.flags
                    ),
                    expect,
                };
            }
            return { pattern, expect };
        },
        testPattern(details, haystack) {
            if ( details.matchAll ) { return true; }
            if ( details.re ) {
                return this.RegExp_test.call(details.re, haystack) === details.expect;
            }
            return haystack.includes(details.pattern) === details.expect;
        },
        patternToRegex(pattern, flags = undefined, verbatim = false) {
            if ( pattern === '' ) { return /^/; }
            const match = /^\/(.+)\/([gimsu]*)$/.exec(pattern);
            if ( match === null ) {
                const reStr = this.escapeRegexChars(pattern);
                return new RegExp(verbatim ? `^${reStr}$` : reStr, flags);
            }
            try {
                return new RegExp(match[1], match[2] || undefined);
            }
            catch {
            }
            return /^/;
        },
        getExtraArgs(args, offset = 0) {
            const entries = args.slice(offset).reduce((out, v, i, a) => {
                if ( (i & 1) === 0 ) {
                    const rawValue = a[i+1];
                    const value = /^\d+$/.test(rawValue)
                        ? parseInt(rawValue, 10)
                        : rawValue;
                    out.push([ a[i], value ]);
                }
                return out;
            }, []);
            return this.Object_fromEntries(entries);
        },
        onIdle(fn, options) {
            if ( self.requestIdleCallback ) {
                return self.requestIdleCallback(fn, options);
            }
            return self.requestAnimationFrame(fn);
        },
        offIdle(id) {
            if ( self.requestIdleCallback ) {
                return self.cancelIdleCallback(id);
            }
            return self.cancelAnimationFrame(id);
        }
    };
    scriptletGlobals.safeSelf = safe;
    if ( scriptletGlobals.bcSecret === undefined ) { return safe; }
    // This is executed only when the logger is opened
    safe.logLevel = scriptletGlobals.logLevel || 1;
    let lastLogType = '';
    let lastLogText = '';
    let lastLogTime = 0;
    safe.toLogText = (type, ...args) => {
        if ( args.length === 0 ) { return; }
        const text = `[${document.location.hostname || document.location.href}]${args.join(' ')}`;
        if ( text === lastLogText && type === lastLogType ) {
            if ( (Date.now() - lastLogTime) < 5000 ) { return; }
        }
        lastLogType = type;
        lastLogText = text;
        lastLogTime = Date.now();
        return text;
    };
    try {
        const bc = new self.BroadcastChannel(scriptletGlobals.bcSecret);
        let bcBuffer = [];
        safe.sendToLogger = (type, ...args) => {
            const text = safe.toLogText(type, ...args);
            if ( text === undefined ) { return; }
            if ( bcBuffer === undefined ) {
                return bc.postMessage({ what: 'messageToLogger', type, text });
            }
            bcBuffer.push({ type, text });
        };
        bc.onmessage = ev => {
            const msg = ev.data;
            switch ( msg ) {
            case 'iamready!':
                if ( bcBuffer === undefined ) { break; }
                bcBuffer.forEach(({ type, text }) =>
                    bc.postMessage({ what: 'messageToLogger', type, text })
                );
                bcBuffer = undefined;
                break;
            case 'setScriptletLogLevelToOne':
                safe.logLevel = 1;
                break;
            case 'setScriptletLogLevelToTwo':
                safe.logLevel = 2;
                break;
            }
        };
        bc.postMessage('areyouready?');
    } catch {
        safe.sendToLogger = (type, ...args) => {
            const text = safe.toLogText(type, ...args);
            if ( text === undefined ) { return; }
            safe.log(`uBO ${text}`);
        };
    }
    return safe;
}

function shouldDebug(details) {
    if ( details instanceof Object === false ) { return false; }
    return scriptletGlobals.canDebug && details.debug;
}

function getRandomTokenFn() {
    const safe = safeSelf();
    return safe.String_fromCharCode(Date.now() % 26 + 97) +
        safe.Math_floor(safe.Math_random() * 982451653 + 982451653).toString(36);
}

/******************************************************************************/

const scriptletGlobals = {}; // eslint-disable-line
const argsList = [["globalThis","break;case"],["Math.random","parseInt(localStorage['\\x"],["Math","localStorage['\\x"],["KeenTracking"],["jQuery","cookie"],["showAds"],["open"],["$","_sp_._networkListenerData"],["document.createElement","jsc.mgid.com"],["document.querySelector","popupBlocked"],["Math","/\\}\\s*\\(.*?\\b(self|this|window)\\b.*?\\)/"],["setTimeout","admc"],["$","window.open"],["decodeURIComponent","shift"],["$","samInitDetection"],["decodeURI","decodeURIComponent"],["$","lobster"],["String.fromCharCode","shift"],["$","AdBlocker"],["addEventListener","displayMessage"],["document.createElement","admc"],["jQuery","TestAdBlock"],["document.getElementById","document.write"],["document.createElement","/l\\.parentNode\\.insertBefore\\(s/"],["$","test-block"],["$","adi"],["$","undefined"],["onload","open"],["$","Adblock"],["ExoLoader"],["puShown","/doOpen|popundr/"],["$","serve"],["document.createElement","script"],["Math","XMLHttpRequest"],["$","ltvModal"],["pop3","window.open"],["jQuery","ready"],["setTimeout","1000"],["atob","decodeURIComponent"],["__ADX_URL_U"],["atob","tabunder"],["RegExp","POSTBACK_PIXEL"],["document.getElementById","undefined"],["eval","replace"],["addEventListener","-0x"],["stop","adblock"],["atob"],["ab1","ab2"],["jQuery","pp12"],["decodeURI","atob"],["jQuery","btoa"],["btoa","BOOTLOADER_LOADED"],["document.getElementsByTagName","onclick"],["awm","location"],["getCookie"],["__ads"],["setTimeout","____POP"],["is_noadblock","window.location"],["$","AdBlockUtil"],["$","show"],["setTimeout","document.querySelector"],["jQuery","document.cookie"],["document.getElementById","adblock"],["JSON.parse","atob"],["navigator","FingerprintJS"],["btoa"],["$","blockAds"],["onload","btoa"],["decodeURI","getScriptFromCss"],["document.getElementById","try"],["$","userAgent"],["document.getElementById","adblocker"],["azar","redirect"],["onload"],["$","azar"],["Math.floor","hilltop"],["$","vglnk"],["setTimeout","aadblock"],["addEventListener","document.createElement"],["readCookieDelit"],["atob","decodeURI"],["Object.defineProperty","trafficjunky"],["$","html"],["__htapop"],["blur"],["$","open"],["document.getElementById","AdBlock"],["document.getElementById","testadblock"],["document.addEventListener","google_ad_client"],["document.getElementById","overlayBtn"],["document.getElementById","ads"],["String.fromCharCode","decodeURIComponent"],["Object.defineProperty","document.body.appendChild"],["$","adblockDetected"],["Object.assign","popunder"],["document.getElementById","ad_block"],["jQuery","AdBlock"],["setTimeout","iframeTestTimeMS"],["setTimeout","runInIframe"],["Math.floor","iframeTestTimeMS"],["Math","='\\x"],["document.createElement","onerror"],["jQuery","dismissAdBlock"],["crakPopInParams"],["onload","onclick"],["document.getElementById","banner"],["document.getElementById","blocker_div"],["document.getElementById","onscroll"],["$","#DontBloxMyAdZ"],["$","#pageWrapper"],["$","banner"],["document.getElementById","adpbtest"],["$","initDetection"],["document.getElementById","alert"],["JSON.parse","showTrkURL"],["Math","/window\\['(?:\\\\x\\d{2}){1}/"],["addEventListener","nextFunction"],["$","adblock"],["$","gandalfads"],["document.createElement","Tool"],["String.fromCharCode","atob"],["document.getElementsByTagName","script"],["$","String.fromCharCode"],["String.prototype.charCodeAt","tabunder"],["$","adBlockChecker"],["$","urlForPopup"],["document.addEventListener","click"],["document.getElementById","overlay"],["setInterval","location"],["Math.floor","vpn"],["adBlockDetected"],["$",".height"],["document.documentElement","break;case $."],["RegExp","0x"],["Math.random","banner"],["spr"],["document.oncontextmenu"],["document.onmousedown"],["document.onkeydown"],["I833"],["jQuery","popunder"],["document.cookie","setOCookie"],["document.addEventListener","initBCPopunder"],["document.getElementById","adblockinfo"],["atob","encodeURIComponent"],["JSON","_0x"],["$","adblocker"],["document.createElement","document.head.appendChild"],["setTimeout","bait.css"],["RegExp","'0x"],["document.createElement","__esModule"],["Math","break"],["XMLHttpRequest","adb"],["document.getElementById","block"],["document.createElement","console"],["document.getElementById","send"],["document.addEventListener","nextFunction"],["Object.defineProperty","break;case"],["document.write","iframe"],["Date","='\\x"],["document.head.appendChild","='\\x"],["btoa","href"],["enlace"],["document.addEventListener","Popup"],["document.getElementsByTagName","appendChild"],["Math.random","Exoloader"],["jQuery","undefined"],["$","AdBlock"],["Promise","overlay"],["document.createElement","overlay"],["document.getElementById","for-variations"],["$","getElementById"],["Math.random","zonefile"],["document.createElement","pop"],["document.write","unescape"],["String.prototype.charAt"],["encodeURIComponent","XMLHttpRequest"],["disableItToContinue"],["adver"],["document.createElement","tcpusher"],["document.querySelectorAll","popMagic"],["loadTool","popping"],["document.getElementById","adsrefresh"],["$","#divDownload"],["$","modal"],["jQuery","fuckAdBlock"],["jQuery","adblock"],["String.fromCharCode","break;"],["Math.round","zonefile"],["jQuery","ai_adb"],["$","setTimeout"],["document.getElementById","deleted"],["$","ads"],["jQuery","adblocker"],["$","MutationObserver"],["Math","'0x"],["$","Math.random"],["doOnce"],["setTimeout","popi"],["googlefc"],["$","detected"],["$","offsetHeight"],["document.getElementById","length"],["document.createElement","adblock"],["$","btoa"],["document.onclick","popunder"],["eval","AdBlock"],["$","prompt"],["$","friendlyduck"],["Math","decodeURIComponent"],["$","onload"],["$","click"],["_pop"],["allclick_Public"],["Math","'\\x"],["String.fromCharCode","window[_0x"],["document.querySelectorAll","adConfig"],["addEventListener","google_ad_client"],["document.querySelector","XF"],["$","hide"],["$",".test"],["$","blocker"],["jQuery","blocker"],["onload","adblock"],["document.getElementById","nextFunction"],["document.createElement","a.adm"],["addEventListener","ADBLOCK"],["jQuery","click"],["eval","ignielAdBlock"],["decodeURIComponent","ai_"],["Light.Popup.create"],["$","zendplace"],["addEventListener","blocker"],["addEventListener","Blocker"],["addEventListener","AdBlocker"],["document.addEventListener","adsBlocked"],["addEventListener","DOMNodeRemoved"],["document.dispatchEvent","CustomEvent"],["onload","adsbygoogle"],["window.onload","devtools"],["window.onload","innerHTML"],["addEventListener","devtools"],["addEventListener","ads"],["document.createElement","antiAdBlockerHandler"],["EventTarget.prototype.addEventListener","delete window"],["document.querySelectorAll","pastepc"],["setTimeout","localStorage"],["fetch","Math.random"],["setTimeout","hommy.mutation.mutation"],["ACtMan"],["atob","/popundersPerIP[\\s\\S]*?Date[\\s\\S]*?getElementsByTagName[\\s\\S]*?insertBefore/"],["$","popMagic"],["WebAssembly","Promise"],["document.createElement","/l\\.parentNode\\.insertBefore\\(s/","/^data:/"],["document.dispatchEvent","myEl"],["Math","zfgloaded"],["JSON.parse","break;case $."],["parseInt","break;case $."],["Math","break;case $."],["String.fromCharCode","/btoa|break/"],["JSON.parse","Promise"],["navigator","break;case $."],["document.createElement",";}}};break;case $."],["Promise","JSON.parse"],["Promise","break;case $."],["JSON","break;case"],["Object","break;case $."],["Object","XMLHttpRequest"],["decodeURI","zfgloadedpopup"],["Math","zfgcodeloaded"],["WebAssembly","atob"],["document.write",".js?_="],["addEventListener","HTMLAllCollection"],["document.createElement","googletag"],["document.createElement","admiral"],["admiral"],["document.createElement","abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+/="],["jQuery","Object"],["addEventListener","AdBlock"],["document.getElementById",".style"],["document.getElementById","adsbygoogle"],["decodeURIComponent","checkAD"],["document.getElementsByTagName","adblocker"],["$","detectAdBlocker"],["Object.defineProperty","XMLHttpRequest"],["String.fromCharCode","/'shift'|break;/"],["document.createElement","shift"],["$","css"],["url","Math.random"],["$",".show"],["$","wrapfabtest"],["Math.floor","document.write"],["$","samAdBlockAction"],["RegExp","googlebot"],["$","advert"],["onload","adb"],["document.getElementById","show_ads"],["document.querySelector","adb"],["$",".init"],["XMLHttpRequest","ActiveXObject"],["setTimeout","Constant"],["document.createElement","insertBefore"],["onload","ajax"],["$","_ads"],["onload","puHref"],["Math","adthrive"],["XMLHttpRequest","null"],["adcashMacros"],["document.getElementsByClassName","offsetParent"],["bannersRequest"],["document.getElementById","body"],["doMyStuff"],["pop_init"],["matchMedia","Adblocker"],["ishop_codes"],["$","/adbl/i"],["$","#advVid"],["__tnt","compatibility"],["String.fromCharCode","constructor"],["Object.defineProperty","clickHandler"],["onbeforeunload"],["document.getElementById","showModal","/^data:text\\/javascript/"],["String.fromCharCode","marginheight"],["mypop"],["jQuery","ads"],["document.getElementsByTagName","adn"],["onload","fetch"],["document.createElement","unblocker"],["Math","replace"],["document.getElementById","adsBlocked"],["jQuery","length"],["XMLHttpRequest","onreadystatechange"],["$","height"],["document.createElement","ignielAdBlock"],["decodeURIComponent","0x"],["jQuery","banner"],["String.fromCharCode","ai_"],["decodeURIComponent","atob"],["document.cookie",":visible"],["mMcreateCookie"],["fetch","status"],["document.getElementById","adsblock"],["document.addEventListener","adsbygoogle"],["$","test"],["fetch","result"],["document.createElement","_htas"],["document.getElementById","style.display"],["Math.floor","ExoLoader"],["quadsOptions"],["document.createElement","loadjscssfile"],["document.createElement","cookie"],["String.prototype.charCodeAt","replace"],["$","adsbygoogle"],["document.getElementById","No"],["document.addEventListener","container.innerHTML"],["Math.imul","charCodeAt"],["document.createElement","adb"],["addEventListener","ai_"],["__PoSettings"],["JSON.parse"],["addEventListener","No"],["b2a"],["document.addEventListener","offsetParent"],["document.getElementById","JSON"],["document.getElementById","stop"],["$","fetch"],["document.getElementById","detect"],["onload","iframe"],["document.createElement","__htas"],["document.getElementsByTagName","tdBlock"],["$","modal-window"],["document.querySelector","_0x"],["Math.imul"],["document.write"],["setTimeout","void 0"],["RegExp","debugger"],["loadAdBlocker"],["Math.random","bait"],["jQuery","No"],["$","RegExp"],["$","adb-btn"],["addEventListener","popunder"],["chAdblock"],["Math","String.fromCharCode"],["setTimeout",".click()"],["$","noConflict"],["setInterval","addAds"],["$","adsBlocked"],["Date","shift"],["jQuery","magnificPopup"],["document.createElement","register"],["String.fromCharCode","ai_adb"],["eval","decodeURIComponent"],["$","/\\.fadeIn|\\.show\\(.?\\)/"],["document.addEventListener","adjsData"],["$","exo"],["document.createElement","htmlAds"],["document.write","lycos_ad"],["String.fromCharCode","replace"],["document.createElement","appendChild"],["navigator","popunder"],["Math","/window\\['(?:\\\\x[0-9a-f]{2}){2}/"],["Math.floor","urls.length"],["Object.defineProperty","break"],["document.getElementById","innerHTML"],["$","sam"],["document.createElement","open"],["confirm","location"],["showAdBlock"],["$","setCookie"],["$onet","adblock"],["goToURL"],["history"],["dataLayer","detectAdBlock"],["nothingCanStopMeShowThisMessage"],["document.createElement","AdBlock"],["document.getElementById","fakeElement"],["JSON.parse","htmlSectionsEncoded"],["showInstruction"],["atob","-0x1"],["$","wbar"],["Script_Manager"],["document.addEventListener","openPopup"],["Array.prototype.indexOf","popunder"],["alert"],["document.createElement","adsBlocked"],["document.onkeypress"],["jQuery","modal"],["Math.floor","Math.random"],["$","push-allow-modal"],["$","localStorage"],["jQuery","ga"],["document.dispatchEvent"],["u_cfg"],["document.createElement","script.src"],["Promise","Adb"],["document.createElement","fakeAd"],["fetch","adsBlocked"],["atob","Uint8Array"],["navigator","shouldPop"],["document.createElement","window.open"],["akadb"],["$","blockAdBlock"],["XV"],["$","XF"],["document.createElement","click"],["ips","adb"],["addEventListener","MutationObserver"],["RegExp","$"],["document.querySelector","adblock"],["WebAssembly","_0x"],["document.getElementById","/Content/_AdBlock/AdBlockDetected.html"],["jQuery","popupAt"],["decodeURIComponent","'shift'"],["document.addEventListener","AdBlock"],["document.createElement","sliding"],["Swal.fire"],["ips.controller.register"],["addEventListener","fetch"],["document.write","cachebuster"],["$","popunder"],["document.cookie","document.head.appendChild"],["OpenInNewTab_Over"],["document.createElement","globalThis"],["addEventListener","smartpop"],["fetch","adblock"],["checkAdsBlocked"],["$","googleAdUrl"],["document.addEventListener","/google_ad_client/"],["$","popCookie"],["EventTarget.prototype.addEventListener","/runPop|aclib|window\\.open/"],["globalThis","shown_at"],["document.write","innerWidth"],["JSON.parse","break;case"],["getCookie","setCookie"],["$","popup"],["document.createElement","break;case"],["$","onclick"],["$","alertmsg"],["$","/adblock/i"],["eval","_0x"],["$","load_banner"],["document.readyState","initializeChecks"],["jQuery","this"],["document.getElementById","deblocker","/^data:text\\/javascript/"],["document.addEventListener","randomNumber"],["$","adBlockAction"],["jQuery","ad-block"],["document.readyState","mdpDeblocker"],["$","samNotice"],["document.readyState","callbackAdsBlocked"],["onbeforeunload","ask"],["addEventListener","location.replace"],["navigator","interceptClickEvent"],["gtag","adblock"],["String.fromCharCode","\\x"],["document.addEventListener","#leaderboardAd"],["document.getElementById","ablk"],["document.getElementById","/adblock/i"],["b2a","ai_adb"],["document.getElementsByClassName","wp-ad"],["setTimeout","aclib.runPop"],["document.onclick","reklama-flash-body"],["Math.floor","src_pop"],["clearTimeout","popundersPerIP"],["setTimeout","document.getElementById"],["document.addEventListener","popunder"],["showTav"],["document.getElementById","window.open"],["document.addEventListener","Adblock"],["$","/undefined|displayAdBlockedVideo/"],["JSON.stringify"],["Math.random","ExoLoader"],["document.getElementById","adb"],["EventTarget.prototype.addEventListener","alert"],["document.createElement","warning"],["$","cdgPops"],["fetch","adb"],["document.createElement","'script'"],["document.createElement","fuckAdBlock"],["document.readyState","adsBlocked"],["$","underpop"],["document.querySelector","akadb"],["aclib"],["document.createElement","zoneid"],["Date.prototype.toISOString","wpadmngr.com"],["document.write","insertAd"],["$","blockThisUrl"],["setTimeout","window.open"],["document.createElement","pop_tag"],["document.createElement",".js"]];
const hostnamesMap = new Map([["jilliandescribecompany.com",[0,270]],["upstream.to",0],["10starhd.*",0],["1337xx.to",0],["alphagames4u.com",[0,357]],["anysex.com",0],["asianclub.*",0],["cheatermad.com",0],["downloadpirate.com",0],["drop.download",[0,88,244]],["dx-tv.com",0],["embed.casa",0],["exee.app",[0,132]],["f2movies.to",0],["fapeza.com",0],["fileone.tv",[0,180]],["films5k.com",0],["gcloud.live",0],["hdss.*",[0,259]],["hdtoday.cc",0],["hentai2read.com",[0,180,270]],["imx.to",0],["javideo.pw",0],["javstream.top",0],["just-upload.com",0],["luluvdo.com",[0,244,252]],["mavplay.*",0],["moviesflix.*",0],["ouo.*",[0,285]],["projectfreetv.*",[0,132,256]],["qdembed.com",0],["sharelink-1.site",0],["sieutamphim.org",0],["streamvid.net",[0,132]],["ujav.me",0],["videobb.*",0],["voirseries.*",0],["adrianmissionminute.com",0],["alejandrocenturyoil.com",[0,270]],["heatherwholeinvolve.com",[0,270]],["jennifercertaindevelopment.com",[0,270]],["johnalwayssame.com",[0,270]],["kellywhatcould.com",[0,270]],["kristiesoundsimply.com",[0,270]],["mariatheserepublican.com",0],["nathanfromsubject.com",[0,270]],["voe.sx>>",0],["javboys.tv>>",0],["qiwi.gg",0],["javfc2.xyz",0],["0deh.com",1],["2glho.org",1],["58n1.com",1],["5mgz1.com",1],["6jlvu.com",1],["c1z39.com",1],["djx10.org",1],["fu-4u3omzw0.nl",1],["guum5.com",1],["hmt6u.com",1],["imdpu9eq.com",1],["kzjou.com",1],["l8e8.com",1],["l99j.com",1],["mee-cccdoz45.com",1],["my4w.com",1],["qa2h.com",1],["qvzidojm.com",1],["tz7z9z0h.com",1],["v1kkm.com",1],["xcoic.com",1],["xo7c.com",1],["z4h4.com",1],["0cbcq8mu.com",2],["2cf0xzdu.com",2],["4k2h4w04.xyz",2],["a6iqb4m8.xyz",2],["afl3ua5u.xyz",2],["jmzkzesy.xyz",2],["scjhg5oh.fun",2],["a-b-f-dd-aa-bb-cctwd3a.fun",2],["mjukb26l.fun",2],["ghajini-4urg44yg.lol",2],["a-b-c-d-e-f9jeats0w5hf22jbbxcrpnq37qq6nbxjwypsy.fun",2],["0x7jwsog5coxn1e0mk2phcaurtrmbxfpouuz.fun",2],["1nmnozg1.fun",2],["222i8x.lol",2],["279kzq8a4lqa0ddt7sfp825b0epdl922oqu6.fun",2],["2btmc2r0.fun",2],["2fb9tsgn.fun",2],["2g8rktp1fn9feqlhxexsw8o4snafapdh9dn1.fun",2],["3a38xmiv.fun",2],["56m605zk.fun",2],["5rr03ujky5me3sjzvfosr6p89hk6wd34qamf.fun",2],["723qrh1p.fun",2],["8mhlloqo.fun",2],["8rm3l0i9.fun",2],["a-b-c-d-e-f7011d0w3j3aor0dczs5ctoo2zpz1t6bm5f49.fun",2],["a-b-c-d-e-fla3m19lerkfex1z9kdr5pd4hx0338uwsvbjx.fun",2],["a-b-f-dd-aa-bb-cc61uyj.fun",2],["a-b-f-dd-aa-bb-ccn1nff.fun",2],["a-b-f-dd-aa-bb-ccyh5my.fun",2],["a-b-f2muvhnjw63ruyhoxhhrd61eszezz6jdj4jy1-b-d-t-s.fun",2],["a-b-f7mh86v4lirbwg7m4qiwwlk2e4za9uyngqy1u-b-d-t-s.fun",2],["a-b-fjkt8v1pxgzrc3lqoaz8fh7pjgygf4zh3eqhl-b-d-t-s.fun",2],["a-b-fnv7h0323ap2wfqj1ruyo8id2bcuoq4kufzon-b-d-t-s.fun",2],["a-b-fqmze5gr05g3y4azx9adr9bd2eow7xoqwbuxg-b-d-t-s.fun",2],["anqkdhcm.nl",2],["bf0skv.org",2],["bk9nmsxs.com",2],["brr-69xwmut5-moo.com",2],["ccyig2ub.nl",2],["eljgocmn.fun",2],["eximeuet.fun",2],["fdvzg.world",2],["file-1bl9ruic-moon.com",2],["file-kg88oaak-embed.com",2],["filemoon-ep11lgxt.xyz",2],["filemoon-oe4w6g0u.xyz",2],["fle-2ggdmu8q-moo.com",2],["fle-5r8dchma-moo.com",2],["fle-rvd0i9o8-moo.com",2],["fu-12qjdjqh.lol",2],["fu-1abozhcd.nl",2],["fu-1fbolpvq.nl",2],["fu-c66heipu.lol",2],["fu-e4nzgj78.nl",2],["fu-hbr4fzp4.lol",2],["fu-hjyo3jqu.lol",2],["fu-l6d0ptc6.lol",2],["fu-m03aenr9.nl",2],["fu-mqsng72r.nl",2],["fu-p6pwkgig.nl",2],["fu-pl1lqloj.nl",2],["fu-v79xn6ct.nl",2],["fu-ys0tjjs1.nl",2],["g8rnyq84.fun",2],["ghajini-04bl9y7x.lol",2],["ghajini-1fef5bqn.lol",2],["ghajini-1flc3i96.lol",2],["ghajini-8nz2lav9.lol",2],["ghajini-9b3wxqbu.lol",2],["ghajini-emtftw1o.lol",2],["ghajini-jadxelkw.lol",2],["ghajini-vf70yty6.lol",2],["ghajini-y9yq0v8t.lol",2],["go-for-it-wgt1a.fun",2],["gorro-9mqnb7j2.fun",2],["gorro-chfzoaas.fun",2],["gorro-ry0ziftc.fun",2],["h8jizwea.fun",2],["huzi6or1.fun",2],["jmtv4zqntu5oyprw4seqtn0dmjulf9nebif0.fun",2],["l1afav.net",2],["mee-6zeqsgv2.com",2],["mee-dp6h8dp2.com",2],["mee-s9o6p31p.com",2],["mkm7c3sm.com",2],["moo-teau4c9h-mkay.com",2],["moon-3uykdl2w-embed.com",2],["moon-fm43w1qv.com",2],["moon-kg83docx.com",2],["moonfile-62es3l9z.com",2],["morgan0928-5386paz2.fun",2],["morgan0928-6v7c14vs.fun",2],["morgan0928-8ufkpqp8.fun",2],["morgan0928-oqdmw7bl.fun",2],["morgan0928-t9xc5eet.fun",2],["semprefi-1h3u8pkc.fun",2],["semprefi-2tazedzl.fun",2],["semprefi-5ut0d23g.fun",2],["semprefi-7oliaqnr.fun",2],["semprefi-8xp7vfr9.fun",2],["semprefi-hdm6l8jq.fun",2],["semprefi-uat4a3jd.fun",2],["semprefi-wdh7eog3.fun",2],["stephenking-00qvxikv.fun",2],["stephenking-3u491ihg.fun",2],["stephenking-7tm3toav.fun",2],["stephenking-c8bxyhnp.fun",2],["stephenking-vy5hgkgu.fun",2],["streamio.to",2],["u26bekrb.fun",2],["u9206kzt.fun",2],["ulike-filter-sowe-canplay-rightlets-generate-themrandomlyl89u8.fun",2],["ur70sq6j.fun",2],["uthr5j7t.com",2],["vdiflcsl.fun",2],["vqjhqcfk.fun",2],["y5vx1atg.fun",2],["z1ekv717.fun",2],["z9sayu0m.nl",2],["oaaxpgp3.xyz",2],["hi0ti780.fun",2],["oimsmosy.fun",2],["unito.life",3],["motherless.com",4],["golem.de",5],["skidrowreloaded.com",6],["faz.net",7],["watchcartoononline.*",[8,132]],["watchcartoonsonline.*",8],["wcostream.*",8],["transfermarkt.*",[9,10]],["torlock.*",11],["torlock2.*",11],["strikeout.*",[11,17]],["viprow.*",[11,244]],["atomohd.*",[11,257]],["atomtt.com",11],["topstreams.*",[11,192]],["streamadblocker.*",[11,132]],["livesport24.net",[11,258]],["pogolinks.*",11],["1stream.*",[11,32,132]],["yts-subs.*",11],["subtitles.cam",11],["poscitech.*",[11,257]],["unblockit.*",11],["f1livegp.*",11],["sportsembed.*",11],["sportsonline.*",[11,403]],["nflstreams.me",[11,64,132]],["moviesonlinefree.net",[11,133]],["bestsolaris.com",11],["daddylivehd.*",[11,132]],["tutelehd.*",11],["watchtvchh.*",11],["liveon.*",11],["tennisstreams.*",[11,64,256,257,258]],["vipleague.*",[11,244]],["dailyuploads.net",12],["nitroflare.com",[12,35]],["oxy.*",[12,430]],["filerice.com",12],["atlasstudiousa.com",12],["mylink.*",[13,256]],["my1ink.*",[13,256]],["myl1nk.*",[13,256]],["myli3k.*",[13,256]],["androidrepublic.org",14],["biqle.*",15],["sxyprn.*",[15,23,180]],["cpmlink.net",15],["grantorrent.*",[15,67]],["grantorrent1.*",15],["turbobit.net",15],["inkapelis.*",[15,77]],["loveroms.*",15],["ver-pelis.*",15],["xrares.com",15],["torrentz2eu.*",[15,85]],["footballstream.tv",15],["mlbstream.tv",15],["nbastream.tv",15],["nflstream.tv",15],["bdsmporn.cc",[15,180]],["cocoporn.net",15],["dirtyporn.cc",[15,180]],["faperplace.com",[15,180]],["freeadultvideos.cc",[15,180]],["freepornstream.cc",15],["generalpornmovies.com",[15,180]],["kinkyporn.cc",[15,180]],["moviesxxx.cc",[15,180]],["movstube.net",15],["onlinefetishporn.cc",[15,180]],["peetube.cc",[15,180]],["pornonline.cc",[15,180]],["porntube18.cc",[15,180]],["streamextreme.cc",[15,180]],["streamporn.cc",[15,180]],["videoxxx.cc",[15,180]],["watchporn.cc",[15,180]],["x24.video",[15,180]],["xxxonline.cc",[15,180]],["xxxonlinefree.com",15],["xxxopenload.com",[15,180]],["dfiles.*",15],["gonzoporn.cc",[15,180]],["onlinexxx.cc",[15,180]],["tvporn.cc",[15,180]],["0xxx.ws",15],["multiup.io",15],["multiup.org",15],["multiup.eu",15],["freesoftpdfdownload.blogspot.com",15],["files.im",[15,257]],["shorterall.com",[15,257]],["spank-and-bang.com",15],["javbel.com",15],["streamingcommunity.*",15],["ekasiwap.com",15],["pornbox.cc",[15,180]],["sturls.com",15],["alluretube.com",15],["anyxvideos.com",15],["fetishtube.cc",15],["fucktheporn.com",15],["italianporn.com.es",15],["japanporn.tv",[15,347]],["lovefap.com",15],["mommysucks.com",15],["mzansinudes.com",15],["napiszar.com",[15,180]],["of-model.com",15],["onlineporn24.com",[15,180]],["onlyfansleaks.tv",15],["porntube15.com",15],["pornvdoxxx.com",15],["sexavgo.com",15],["sexdiaryz.*",[15,23]],["store-of-beats.ru",15],["hispasexy.org",15],["acervodaputaria.com.br",15],["mmopeon.ru",15],["mangaraw.org",15],["uporn.icu",[15,180]],["sexgayplus.com",15],["archivebate.com",[15,180]],["all3do.com",[15,244]],["d0o0d.com",[15,132]],["do0od.com",[15,132]],["do7go.com",[15,244]],["dood.*",[15,132]],["dooodster.com",[15,244]],["doply.net",[15,244]],["ds2video.com",[15,132]],["vidply.com",[15,244]],["wetter.com",16],["animepahe.*",[17,256]],["kwik.*",[17,255]],["seehd.*",17],["audioz.download",17],["peeplink.in",17],["tamilyogi.*",17],["urlpay.net",17],["javtiful.com",[17,44,235]],["kropic.com",[17,180]],["ricettafitness.com",17],["yourporngod.com",17],["freeomovie.to",[17,180]],["hpaudiobooks.*",17],["xxxmax.net",17],["imagenesderopaparaperros.com",[17,258]],["xxvideoss.org",17],["zonebourse.com",18],["aofsoru.com",19],["yts.*",[20,257]],["imgdrive.net",[21,22]],["imgwallet.com",[21,22]],["imgadult.com",22],["imgtaxi.com",22],["gogoanime.*",[23,38]],["hdfull.*",23],["imgdawgknuttz.com",[23,256]],["leechall.com",23],["10convert.com",23],["2girls1cup.ca",23],["animez.org",[23,244]],["besthdgayporn.com",[23,180]],["bigojav.com",23],["bookfrom.net",23],["ddd-smart.net",23],["drivenime.com",23],["favoyeurtube.net",23],["fucksporn.com",23],["fullxcinema1.com",23],["gdrivelatinohd.net",[23,132,244]],["gigmature.com",23],["hentairead.io",23],["homemoviestube.com",[23,270]],["javboys.*",23],["javbraze.com",[23,270]],["javchill.com",23],["javhat.tv",[23,270]],["javhd.today",[23,270]],["javhdz.today",[23,270]],["javseen.tv",[23,270]],["javup.org",23],["kaliscan.me",23],["kisscos.net",[23,44]],["kmansin09.*",23],["leermanga.net",23],["mangajikan.com",23],["mangamovil.net",23],["naijauncut.com",23],["nicomanga.com",23],["nudeslegion.com",23],["onlinework4all.com",[23,255]],["otomi-games.com",[23,180,258]],["piratehaven.xyz",23],["poapan.xyz",[23,270]],["porn00.org",[23,180]],["pornohubonline.com",23],["pornxp.com",[23,180]],["raw1001.net",23],["rawinu.com",23],["safefileku.com",23],["shemale6.com",23],["shemaleup.net",23],["socigames.com",23],["streamup.ws",[23,244]],["tatli.biz",23],["teenager365.com",23],["theblank.net",23],["transflix.net",23],["weloma.art",[23,422]],["welovemanga.one",[23,422]],["worthcrete.com",23],["kfapfakes.com",23],["xmegadrive.com",23],["simply-hentai.com",[23,180]],["onlinepornhub.net",23],["yifysubtitles.vip",23],["javenspanish.com",[23,180]],["moviesjoy.*",[23,132]],["moviegan.*",23],["adslink.pw",[23,132,180]],["porhubvideo.com",[23,43]],["webseriessex.com",[23,43]],["panuvideo.com",[23,43]],["pornktubes.net",[23,43]],["jpopsingles.eu",[23,132,244,476]],["123link.*",[24,25,26]],["pakkotoisto.com",26],["alrincon.com",27],["faps.club",27],["sexlivesex.net",27],["camsstream.com",27],["redvido.com",27],["vortez.net",28],["beermoneyforum.com",28],["ephoto360.com",28],["pornxs.com",29],["perfectgirls.*",[29,180]],["perfektdamen.*",29],["hentaipulse.com",29],["vivud.com",29],["newsextv.com",29],["anyporn.com",29],["eroprofile.com",29],["absoluporn.*",29],["mangoporn.net",30],["celebritymovieblog.com",30],["fuckundies.com",30],["pandamovies.pw",[30,32]],["khatrimaza.*",30],["watchpornx.com",30],["eskiceviri.blogspot.com",30],["hentaianimedownloads.com",30],["boobsrealm.com",30],["ah-me.com",31],["realgfporn.com",32],["fapdig.com",32],["mangovideo.*",32],["sound-park.*",[32,85]],["soundpark.*",[32,85]],["soundpark-club.*",[32,85]],["watchfreexxx.net",32],["gdtot.*",[32,132,244]],["tusfiles.com",[32,265]],["readcomicsonline.ru",32],["afrodity.sk",32],["brato.bg",32],["cinema21fullmovie.com",32],["cotannualconference.org.uk",32],["couponsuniverse.com",32],["cycraracing.com",32],["dahh.net",32],["dlhe-videa.sk",32],["elmalajeno.com",32],["extreme-board.com",32],["free-famous-toons.com",32],["istanbulescortnetworks.com",32],["ok-th.com",32],["payt.com",32],["pcparsi.com",32],["podkontrola.pl",32],["redtubemov.com",32],["shtab.su",32],["spiritword.net",32],["latesthdmovies.*",[32,43]],["comixzilla.com",32],["indianporn365.net",32],["brillen.de",32],["watch-series.*",33],["watchseries.*",[33,132]],["limetorrents.*",[33,94]],["vidcloud.*",[33,38]],["moviflex.*",33],["iir.ai",33],["01fmovies.com",[33,255]],["123moviesfun.is",33],["bmovies.*",[33,256]],["bolly4umovies.*",33],["putlocker.*",[33,132,244,255]],["deseneledublate.com",33],["movie123.*",33],["luxuretv.com",34],["planetsuzy.org",36],["onlinetv.planetfools.com",37],["adsrt.*",38],["fullywatchonline.com",38],["myvidmate.*",38],["voirfilms.*",38],["converto.io",[38,255]],["tamilmv.*",38],["streamingworld.*",[38,258]],["watchjavonline.com",38],["skpb.live",38],["faucethero.com",38],["livegore.com",38],["123unblock.*",[38,307]],["2umovies.*",38],["a2zapk.*",[38,478]],["safestream.cc",[38,250,450]],["feet9.com",39],["short.pe",[40,41,255]],["micloudfiles.com",40],["coinfaucet.io",[40,268]],["nekopoi.*",[40,270]],["deepbrid.com",42],["appstore-discounts.com",42],["xianzhenyuan.cn",42],["k511.me",42],["dozarte.com",42],["getfreesmsnumber.com",42],["fstore.biz",42],["devdrive.cloud",42],["upzone.cc",[42,255]],["nifteam.info",42],["file-upload.*",42],["pinsystem.co.uk",43],["scrapywar.com",43],["freecoursesite.com",43],["dutchycorp.*",43],["aquariumgays.com",43],["uptechnologys.com",43],["sevenjournals.com",43],["aiimgvlog.fun",[43,217]],["moderngyan.com",43],["sattakingcharts.in",43],["freshbhojpuri.com",43],["bgmi32bitapk.in",43],["bankshiksha.in",43],["earn.mpscstudyhub.com",43],["earn.quotesopia.com",43],["money.quotesopia.com",43],["best-mobilegames.com",43],["learn.moderngyan.com",43],["bharatsarkarijobalert.com",43],["quotesopia.com",43],["creditsgoal.com",43],["blog4nx.com",43],["1xanime.in",43],["anhdep24.com",43],["asideway.com",43],["tecnotutoshd.net",43],["world4ufree.*",[43,257]],["freemagazines.top",43],["movi.pk",[43,244]],["vectogravic.com",43],["downloadcursos.top",43],["knightnoscanlation.com",43],["freejav.guru",43],["193.124.191.200",43],["cardiagn.com",43],["routech.ro",43],["gigacourse.com",43],["switch520.com",43],["techymedies.com",43],["samuraiscan.com",43],["electomania.es",43],["vfxdownload.net",43],["rtilinks.com",43],["pcwarehub.com",43],["taregna.com",43],["moddedguru.com",43],["crazytechgo.com",43],["mlsbd.*",[43,258]],["thecustomrom.com",[43,229]],["phanmemmaytinh.net",43],["wpking.in",43],["itdmusics.com",43],["bullfrag.com",43],["actresstoday.com",43],["sportsdark.com",43],["freecoursesites.com",43],["gcertificationcourse.com",43],["infinityblogger.in",43],["chiangraitimes.com",43],["aresmanga.com",43],["dubznetwork.com",[43,380]],["needrombd.com",[43,256]],["bithub.win",43],["freeshib.biz",[43,101]],["whats-on-netflix.com",43],["dongknows.com",43],["akumanimes.com",43],["nullpk.com",[43,257]],["apkmagic.com.ar",43],["freedwnlds.com",43],["hentaiseason.com",43],["allpremium.net",43],["smgplaza.com",43],["topsporter.net",[43,136,426]],["allotech-dz.com",43],["daemonanime.net",[43,88,180,253]],["simulatormods.com",43],["7xm.xyz",43],["hayatarehber.com",43],["173.249.8.3",43],["coursedrive.org",43],["dktechnicalmate.com",43],["bitcosite.com",43],["akw.to",43],["babelwuxia.com",43],["haber.eskisehirde.net",43],["projectlive.info",43],["gamedrive.org",43],["manga4you.net",43],["medeberiyas.com",[43,132]],["ravenscans.com",43],["fap-nation.org",43],["45.86.86.235",43],["cryptofaucet.xyz",43],["mastaklomods.com",43],["tecnoyfoto.com",43],["freemagazinespdf.com",43],["rpupdate.cc",43],["butterpolish.com",43],["buxfaucet.com",43],["faucetcaptcha.co.in",43],["gameblog.in",43],["needbux.com",43],["digter8.com",43],["trigonevo.com",43],["dreamdth.com",[43,59]],["freemodsapp.in",43],["onlytech.com",[43,343]],["dewimg.*",44],["imgtown.*",44],["imgviu.*",44],["mazpic.*",44],["outletpic.*",44],["picrok.*",44],["highporn.net",[44,180]],["watchmdh.to",44],["zetporn.com",44],["javfor.tv",44],["1bitspace.com",[44,300]],["mgnet.xyz",[44,354]],["hideout.*",45],["stream2watch.*",[46,258]],["haxmaps.com",47],["animeflv.*",[48,244]],["hyperdebrid.*",49],["divxtotal.*",50],["divxtotal1.*",50],["birdsandblooms.com",51],["bombshellbling.com",51],["dorkly.com",51],["dryscalpgone.com",51],["eclypsia.com",51],["familyhandyman.com",51],["gala.fr",51],["gentlemansgazette.com",51],["homeschoolgiveaways.com",51],["hotbeautyhealth.com",51],["ketoconnect.net",51],["mom4real.com",51],["mynaturalfamily.com",51],["oneessentialcommunity.com",51],["pageflutter.com",51],["printablecrush.com",51],["psychologyjunkie.com",51],["skinnyms.com",51],["skintagsgone.com",51],["stayglam.com",51],["tasteandtellblog.com",51],["thecelticblog.com",51],["thecozyapron.com",51],["theendlessmeal.com",51],["thehappierhomemaker.com",51],["thelovenerds.com",51],["yellowblissroad.com",51],["pelisplus2.*",52],["minecraftraffle.com",53],["desiupload.*",54],["kino-zeit.de",54],["uploadraja.com",54],["vintage-erotica-forum.com",[55,56]],["siamfishing.com",57],["haaretz.co.il",58],["haaretz.com",58],["farmeramania.de",59],["douploads.*",59],["dloady.com",59],["jacquieetmichelelite.com",59],["hostingunlock.com",59],["vipracing.*",59],["hwreload.it",59],["mangafreak.me",60],["crazyshit.com",61],["anonymousemail.me",62],["auto-data.net",62],["seeitworks.com",62],["gogodl.com",62],["bg-gledai.*",62],["traductionjeux.com",62],["itopmusics.com",[62,132,250]],["ttsfree.com",62],["vipbox.*",63],["l23movies.*",63],["123moviess.*",63],["123movieshub.*",[63,132]],["modagamers.com",63],["cracksports.me",63],["forgepattern.net",63],["sportsonline.si",63],["estrenosflux.*",63],["antenasports.ru",[63,132]],["cdn.xsportbox.com",63],["claplivehdplay.ru",[63,132,244]],["cuervotv.me",63],["embedstream.me",[63,132,265]],["viwlivehdplay.ru",63],["roystream.com",[63,132]],["cricstream.me",64],["cety.app",64],["exe-urls.com",64],["exego.app",64],["cutlink.net",64],["cutsy.net",64],["cutyurls.com",64],["cutty.app",64],["cutnet.net",64],["jixo.online",64],["efhjd.com",64],["arcjav.com",[64,180]],["buffstreams.*",[64,132]],["game3rb.com",[64,258]],["igg-games.com",[64,78]],["manhwalist.com",64],["mc-hacks.net",64],["miraculous.*",64],["mycivillinks.com",64],["s2dfree.to",64],["soap2day.*",[64,244,256]],["tv247.us",64],["vidsrc.*",[64,132,244,256]],["vipboxtv.*",64],["woiden.com",64],["wonderapk.com",64],["worldcupstream.pm",64],["1cloudfile.com",[64,132]],["sunci.net",64],["yoykp.com",64],["tennisonline.me",[64,132]],["buffsports.me",[64,132]],["royale-games.com",64],["wkyc.com",65],["video1tube.com",65],["hotcopper.com.au",66],["ddlvalley.*",68],["youmath.it",69],["nulledteam.com",70],["nzbstars.com",71],["vixenless.com",72],["camslib.com",73],["camwhores.*",73],["camwhorestv.*",73],["anon-v.com",[73,80]],["cambabe.*",[73,103]],["camgirlbay.net",73],["ievaphone.com",73],["camclips.tv",73],["dirtyship.com",73],["thotvids.com",73],["rodude.com",73],["uploadbaz.*",[73,372]],["bestialitytaboo.tv",74],["bestialitysextaboo.com",74],["mujeresdesnudas.club",74],["videos1002.com",74],["hdbraze.com",75],["boards.net",76],["freeforums.net",76],["proboards.com",76],["camwhoresbay.com",79],["javbangers.com",[79,142,304]],["redtube.*",81],["pornhub.*",81],["dailyfreebits.com",82],["naughtymachinima.com",83],["peliculas24.*",84],["gifhq.com",[85,254]],["udvl.com",85],["gochyu.com",85],["temp-mails.com",86],["btcadspace.com",86],["undeniable.info",87],["klartext-ne.de",88],["flycutlink.com",[88,180]],["mmo69.com",88],["ysokuhou.blog.jp",88],["ads-ti9ni4.blogspot.com",88],["bouamra.blogspot.com",88],["cintateknologi.com",88],["este-walks.net",88],["funnymadworld.blogspot.com",88],["gfilex.blogspot.com",88],["intest.tv",88],["irasutoya.blogspot.com",88],["laurasia.info",88],["pramejarab.blogspot.com",88],["thelibrarydigital.blogspot.com",88],["tienganhedu.com",88],["tienichdienthoai.net",88],["xbox360torrent.com",88],["xn--k9ja7fb0161b5jtgfm.jp",88],["officecoach24.de",88],["samaysawara.in",88],["webcreator-journal.com",88],["dl.3dmodelshare.org",88],["nandetribune.com",88],["withukor.com",88],["mizugigurabia.com",88],["hayamimi-gunpla.com",88],["forogore.com",88],["codare.fun",88],["aimasummd.blog.fc2.com",88],["dokuo666.blog98.fc2.com",88],["metamani.blog15.fc2.com",88],["newssokuhou666.blog.fc2.com",88],["touhoudougamatome.blog.fc2.com",88],["youkaiwatch2345.blog.fc2.com",88],["mysafe.stisda.ac.id",88],["mediapemersatubangsa.com",88],["love-stoorey210.net",88],["megawypas.com",88],["oneotv.com",88],["bangsaku.web.id",88],["5ggyan.com",88],["burnbutt.com",88],["valuable.hatenablog.com",88],["gaget.hatenablog.com",88],["lib.hatenablog.com",88],["descargasok.*",88],["gametter.com",88],["toramemoblog.com",88],["akw.cam",88],["chartstream.net",88],["ovflixx.fun",88],["blog.livedoor.jp",88],["blogx.almontsf.com",88],["moviejones.de",89],["tennisactu.net",90],["btcbitco.in",[90,240,241]],["btcsatoshi.net",90],["wiour.com",90],["bitssurf.com",90],["pirateproxy.*",[91,92]],["thehiddenbay.com",91],["mangalek.com",91],["phsensei.com",91],["fileborder.com",91],["plc247.com",91],["thurrott.com",93],["file4go.*",[95,244]],["andiim3.com",96],["kompas.com",97],["namemc.com",98],["pockettactics.com",99],["tribunnews.com",100],["camgirlfap.com",[101,180]],["scat.gold",[101,180]],["mdbekjwqa.pw",101],["fr.streamon-sport.ru",[101,132]],["hoca4u.com",101],["bitzite.com",101],["katfile.com",101],["vinylcollective.com",102],["cambay.tv",[103,104]],["caminspector.net",[103,104]],["camporn.tube",[103,104]],["camwhorescloud.com",[103,104]],["camwhorespy.com",[103,104]],["camwhoria.com",103],["camvideos.org",[103,104]],["cambro.tv",[103,142,180]],["camlovers.tv",103],["camwhoreshd.com",104],["camflow.tv",104],["camhoes.tv",104],["gaytail.com",104],["milfnut.*",104],["guitarnick.com",105],["homebooster.de",106],["newhome.de",106],["porconocer.com",107],["scamalot.com",108],["beautypackaging.com",109],["coatingsworld.com",109],["contractpharma.com",109],["happi.com",109],["inkworldmagazine.com",109],["labelandnarrowweb.com",109],["mpo-mag.com",109],["nutraceuticalsworld.com",109],["odtmag.com",109],["printedelectronicsnow.com",109],["savevideo.me",110],["situsberita2terbaru.blogspot.com",111],["syracusefan.com",112],["argio-logic.net",113],["typinggames.zone",113],["uplink.my.id",113],["x08.ovh",[114,115]],["3ixcf45.cfd",[114,401]],["76078rb.sbs",[114,401]],["defienietlynotme.com",[114,132,401]],["embedme.*",[114,132,401]],["filemooon.top",[114,401]],["finfang.*",[114,132,401]],["fmembed.cc",[114,132,401]],["fmoonembed.pro",[114,132,401]],["hellnaw.*",[114,132,401]],["moonembed.*",[114,132,401]],["rgeyyddl.skin",[114,203,401]],["sbnmp.bar",[114,132,401]],["sulleiman.com",[114,132,401]],["vpcxz19p.xyz",[114,401]],["z12z0vla.*",[114,132,401]],["4download.net",116],["globalssh.net",116],["debgen.fr",116],["jumpmanclubbrasil.com.br",116],["cheatglobal.com",116],["hd-tch.com",116],["anonymousceviri.com",116],["larvelfaucet.com",116],["abukabir.fawrye.com",116],["sshconect.com.br",116],["blograffo.net",116],["arab4media.com",116],["uvnc.com",116],["pythonmatplotlibtips.blogspot.com",116],["addonbiz.com",116],["gagaltotal666.my.id",116],["sms-receive.net",117],["reverso.net",117],["vz.lt",117],["pornone.com",[117,180]],["3dprintersforum.co.uk",118],["gamecopyworld.*",119],["xpaja.net",120],["dailysport.*",120],["rojadirecta-tv-en-vivo.blogspot.com",120],["chochox.com",120],["rapbhe.com",120],["mrdeepfakes.com",121],["imagetwist.com",121],["mixdrop.*",122],["mixdrp.*",122],["milfzr.com",123],["wemakesites.net",124],["alimaniacky.cz",125],["za.gl",[126,127,128]],["wiztube.xyz",129],["moretvtime.*",130],["televisiongratishd.com",[130,255]],["tvguia.es",131],["6hiidude.gold",132],["0123movie.*",132],["10starhub.com",132],["11xmovies.*",[132,244]],["123chill.*",132],["123mkv.*",132],["123movies-free.*",132],["123movies-org.*",132],["123movies.*",132],["123moviesfree.*",[132,257]],["123movieweb.*",132],["190.115.18.20",132],["1direct-cloud.*",132],["1hd.to",132],["1movieshd.*",132],["1qwebplay.xyz",132],["1todaypk.*",132],["1vid1shar.space",132],["2kmovie.*",132],["3kmovies.*",132],["4movierulz.*",132],["4movierulz1.*",132],["5movies.*",132],["5moviess.com",132],["6hiidude.art",132],["720pflix.*",[132,244]],["7moviesrulz.*",132],["7starhd.*",[132,244,285]],["7starmv.com",132],["9anime.pe",132],["9goals.live",132],["9kmovies.*",[132,257]],["9xflix.*",132],["a8ix.*",132],["acn.vin",132],["adblocktape.*",132],["aflizmovies.com",132],["ak4eg.*",[132,433]],["algodaodocescan.com.br",[132,180]],["aliezstream.pro",132],["amsmotoresllc.com",132],["anihdplay.com",132],["animeonline.ninja",132],["animesultra.net",132],["animixplay.*",132],["aniwatch.*",132],["antennasports.ru",132],["arbsd.*",132],["asianhdplay.*",132],["atishmkv.*",132],["b4ucast.com",132],["backfirstwo.site",132],["bdmusic28.*",132],["blogesque.net",132],["bolly2tolly.*",132],["bollyflix.*",132],["bowfile.com",[132,265]],["cinemabaz.com",132],["clickndownload.*",[132,244]],["comedyshow.to",132],["cool-etv.net",132],["couchtuner.*",[132,133]],["crackstreamshd.click",132],["crvsport.ru",132],["d0000d.com",132],["d000d.com",132],["daddylive1.*",132],["darkibox.com",132],["direct-cloud.*",132],["divicast.com",132],["divxfilmeonline.net",132],["dlhd.*",132],["doods.pro",132],["dooood.*",132],["downloadhub.*",132],["ds2play.com",132],["dwlinks.buzz",132],["egybest.*",132],["embedpk.net",132],["embedplayer.*",132],["embtaku.*",132],["emovies.*",132],["encurtandourl.com",132],["engvideo.net",132],["esportivos.*",132],["explorosity.net",132],["extremosports.club",132],["f123movies.com",132],["faselhd-watch.*",132],["faselhd.*",132],["faselhdwatch.*",132],["filemooon.*",132],["film4e.com",132],["filmeserialeonline.org",132],["filmy-hit.*",132],["filmygod.*",132],["filmyhitt.com.in",132],["fiveyardlab.com",132],["flashsports.org",132],["flixhq.*",132],["flostreams.xyz",[132,244]],["flybid.net",132],["fmoonembed.*",132],["fmoviesfree.*",132],["fmovieszfree.com",132],["focus4ca.com",132],["foot2live.cc",132],["footballandress.club",132],["footybite.to",[132,244]],["footyhunter.lol",132],["forex-trnd.com",132],["freemovies.*",132],["freemoviesfull.com",132],["freetvsports.com",[132,244]],["french-streams.cc",132],["fsl-stream.lu",132],["fslinks.org",132],["fullfreeimage.com",132],["futemax.zip",132],["game-2u.com",132],["gamovideo.com",132],["gdrivelatino.net",132],["gembedhd.com",132],["globalstreams.xyz",132],["gocast.pro",132],["gocast2.com",132],["godzcast.com",132],["gogohd.*",132],["gokutv.*",132],["gomovies.*",132],["goone.pro",132],["gotaku1.com",132],["hamburgerinsult.com",132],["harimanga.com",132],["hdfriday.*",132],["hdhub4u.*",[132,244]],["hdmoviehub.*",132],["hdmovies23.*",132],["hdtoday.tv",132],["hexload.com",[132,244]],["hianime.*",132],["hihihaha1.xyz",132],["hitsports.pro",132],["hollymoviehd.*",132],["huboflink.in",132],["hurawatchz.to",132],["iflixmovies.*",132],["imagelovers.com",132],["isaidub6.net",132],["itopmusic.com",132],["japscan.lol",132],["jockantv.com",[132,257]],["kaido.to",132],["kerapoxy.*",[132,180,401]],["kickassanime.*",132],["kinoger.*",132],["klubsports.*",132],["koora.vip",132],["kunmanga.com",132],["kuttymovies1.com",132],["lewblivehdplay.ru",[132,244]],["ligaset.com",132],["likemanga.io",132],["ling-online.*",132],["linkedmoviehub.top",132],["livestreames.us",132],["locatedinfain.com",132],["lrepacks.net",132],["mangaraw.*",[132,270]],["mangareader.to",132],["maxstream.*",132],["mcrypto.club",132],["mega4upload.com",132],["megadb.net",132],["megafilmeshd50.com",132],["megaupto.com",132],["mhdsports.*",132],["mhdsportstv.*",132],["mhdtvsports.*",132],["mkvcinemas.*",[132,272]],["mkvmoviespoint.autos",132],["mlwbd.*",132],["mmastreams.me",132],["movembed.cc",132],["moviebaaz.*",132],["moviekids.tv",132],["movielinkhub.xyz",132],["movieplay.*",132],["movies2k.*",[132,257]],["movies4u.*",[132,244]],["movies4u3.*",132],["moviesda4.*",132],["movieshd.watch",132],["moviesrulz.*",132],["moviestowatch.tv",132],["moviesverse.*",[132,257]],["movieuniverse.*",132],["moviezwap.*",[132,244]],["mp3fusion.net",[132,257]],["mp4upload.com",132],["mreader.co",132],["multicanais.*",132],["mydownloadtube.*",132],["myflixertv.to",132],["myflixerz.*",132],["mylivestream.pro",132],["naijachoice.com.ng",132],["naijanowell.com",132],["netfilmes.org",132],["netizensbuzz.com",132],["niadd.com",132],["nizarstream.com",132],["noblocktape.*",[132,265]],["nohost.one",132],["nolive.me",[132,265]],["nowmaxtv.com",132],["nowsports.me",132],["nowsportv.nl",132],["odiasia.sbs",132],["ogomovies.*",132],["oii.io",132],["olalivehdplay.ru",132],["onepiecepower.com",132],["optimizepics.com",132],["pahe.plus",132],["pesktop.com",132],["pkspeed.net",132],["pladrac.net",132],["playgo1.cc",132],["poclivetv.com",132],["poophq.com",132],["poscitechs.*",132],["project-free-tv.*",132],["qqwebplay.xyz",[132,244]],["radamel.icu",132],["rahim-soft.com",132],["reddit-soccerstreams.com",132],["repack-games.com",132],["rgeyyddl.*",132],["ronaldo7.pro",132],["s.to",[132,257]],["s3taku.com",132],["send.cm",[132,265]],["serienstream.*",132],["series2watch.*",132],["seriesonline.*",132],["seriestv.org",132],["shadowrangers.live",132],["shahed4u.*",[132,257]],["shaheed4u.*",132],["share.filesh.site",132],["sharedisk.*",132],["shavetape.*",[132,258]],["shinden.pl",[132,286]],["shoot-yalla.live",132],["shortenlinks.top",132],["sinvida.me",132],["smoner.com",132],["soap2day-online.com",132],["soaper.tv",132],["soccer100.shop",132],["soccerstream100.to",132],["sportsbuff.stream",132],["sportshub.*",132],["ssoap2day.*",[132,256]],["stfly.*",132],["strcloud.*",132],["streamcloud.*",132],["streamhd247.*",132],["streamhub.*",[132,180]],["streamnoads.com",132],["streamonsport99.*",132],["streamtape.*",[132,244,260]],["strtapewithadblock.*",132],["swatchseries.*",132],["swiftload.io",[132,244]],["tamilprint30.*",[132,244]],["tapeadsenjoyer.com",132],["tapeadvertisement.com",132],["tapeantiads.com",132],["tapeblocker.com",132],["tapelovesads.org",132],["tapenoads.com",132],["tapewithadblock.org",132],["techgeek.digital",132],["temp.modpro.co",132],["theflixertv.to",132],["thenextplanet1.*",132],["tii.la",132],["tnhitsda.net",132],["todaypk.*",132],["topcartoons.tv",132],["torovalley.net",132],["totalsportek.*",[132,244]],["trendytalker.com",132],["turcasmania.com",[132,256,257]],["tvfutbol.info",132],["tvpclive.com",132],["up-4ever.net",132],["upbaam.com",132],["uploadhub.*",132],["uproxy.*",132],["uptomega.net",132],["usgate.xyz",[132,244]],["uupbom.com",132],["vadbam.net",132],["vavada5com.com",132],["vdbtm.shop",132],["veev.to",132],["vegamovie.*",132],["vid-guard.com",132],["vidcloud9.*",[132,258]],["videoplayer.*",132],["vido.*",132],["vidspeed.cc",132],["vidstreams.net",132],["vidtube.one",[132,244]],["viidshar.com",132],["vikistream.com",[132,257]],["vixcloud.co",[132,244]],["volokit2.com",[132,244]],["watchmovierulz.*",132],["watchmovies.*",132],["watchomovies.*",[132,257]],["watchonlinemoviespk.*",132],["watchop.live",132],["watchseries1.*",[132,180]],["wecast.to",132],["worldstreams.click",132],["xoxocomic.com",132],["xsportbox.com",132],["yesmovies4u.*",132],["yu2be.com",132],["zamundatv.com",132],["zoechip.cc",132],["zvision.link",132],["euro2024direct.ru",[132,476]],["stagatv.com",132],["stagatvfiles.com",132],["bingsport.xyz",132],["lol-foot.ru",132],["soccerinhd.com",132],["stylisheleg4nt.com",132],["filegram.to",132],["eurostreaming.casino",132],["sportsurge.net",132],["mlbbox.me",[132,244]],["easy-coin.*",134],["hackstore.me",135],["drivelinks.me",[136,137]],["hackshort.me",[136,137]],["pelislinks.me",[136,137]],["freeserverhostingweb.club",[136,137,138]],["me-encantas.com",[136,137,138]],["mexicogob.com",[136,137,138]],["noticiascripto.site",[136,137,138]],["tanfacil.net",[136,137,138]],["tecnoaldia.net",[136,137,138]],["todoandroid.live",[136,137,138]],["sportshub.to",[136,426]],["dropmms.com",138],["pctfenix.*",[139,258]],["pctnew.*",[139,258]],["nextorrent.*",140],["pornfactors.com",140],["urlgalleries.net",141],["vipr.im",142],["dz4up1.com",143],["mexa.*",143],["ciudadgamer.com",144],["ovagames.com",145],["go.bucketforms.com",146],["sythe.org",[146,282]],["mz-web.de",147],["m.kuku.lu",148],["macrotrends.net",149],["lippycorn.com",150],["720pxmovies.blogspot.com",151],["oko.sh",152],["ratemyteachers.com",153],["isminiunuttum.com",153],["desiremovies.*",154],["notebookcheck-ru.com",155],["fc.lc",156],["fc-lc.com",156],["toonvideos.net.in",156],["blog.40ch.net",156],["embed-channel.stream",156],["devotag.com",156],["uyduportal.net",156],["subedlc.com",156],["rosefile.net",156],["streameast.*",[157,244]],["sexvid.*",158],["hdtube.porn",158],["rat.xxx",158],["barefeetonthedashboard.com",[159,160]],["bargainbriana.com",[159,160]],["betterbuttchallenge.com",[159,160]],["bike-urious.com",[159,160]],["blwideas.com",[159,160]],["eartheclipse.com",[159,160]],["entertainment-focus.com",[159,160]],["fanatik.com.tr",[159,160]],["foreverconscious.com",[159,160]],["foreversparkly.com",[159,160]],["getdatgadget.com",[159,160]],["goodnewsnetwork.org",[159,160]],["greenarrowtv.com",[159,160]],["hbculifestyle.com",[159,160]],["heysigmund.com",[159,160]],["hodgepodgehippie.com",[159,160]],["homestratosphere.com",[159,160]],["indesignskills.com",[159,160]],["katiescucina.com",[159,160]],["knowyourphrase.com",[159,160]],["letsworkremotely.com",[159,160]],["lizs-early-learning-spot.com",[159,160]],["ledauphine.com",[159,160]],["leprogres.fr",[159,160]],["milliyet.com.tr",[159,160]],["mjsbigblog.com",[159,160]],["pinoyrecipe.net",[159,160]],["prepared-housewives.com",[159,160]],["recipesforourdailybread.com",[159,160]],["redcarpet-fashionawards.com",[159,160]],["republicain-lorrain.fr",[159,160]],["savespendsplurge.com",[159,160]],["savingadvice.com",[159,160]],["shutupandgo.travel",[159,160]],["spring.org.uk",[159,160]],["stevivor.com",[159,160]],["tamaratattles.com",[159,160]],["tastefullyeclectic.com",[159,160]],["theavtimes.com",[159,160]],["thechroniclesofhome.com",[159,160]],["thisisourbliss.com",[159,160]],["tinyqualityhomes.org",[159,160]],["turtleboysports.com",[159,160]],["ultimateninjablazingx.com",[159,160]],["universfreebox.com",[159,160]],["utahsweetsavings.com",[159,160]],["vgamerz.com",[159,160]],["wheatbellyblog.com",[159,160]],["yummytummyaarthi.com",[159,160]],["closermag.fr",160],["seireshd.com",161],["pivigames.blog",162],["playpaste.com",163],["thecrazytourist.com",164],["pornult.com",165],["izzylaif.com",166],["gamefront.com",167],["interfans.org",167],["nirjonmela.com",167],["turkmmo.com",167],["washingtonpost.com",[168,169]],["samash.com",170],["okanime.*",[171,257]],["arcadeprehacks.com",172],["iporntv.net",173],["xtapes.to",174],["yuvutu.com",175],["exey.io",[176,177,257]],["pornclassic.tube",178],["tubepornclassic.com",[178,179]],["voyeurhit.*",178],["upornia.*",178],["hotmovs.*",178],["thegay.*",178],["senzuri.tube",178],["txxxporn.tube",178],["hclips.com",178],["hdzog.*",178],["tuberel.com",178],["shemalez.com",178],["pussyspot.net",180],["wildpictures.net",180],["4khd.com",180],["141tube.com",180],["18porncomic.com",180],["19-days-manga.com",180],["1piecemanga.com",180],["1punchman-manga.com",180],["1teentubeporn.com",180],["1youngteenporn.com",180],["3dhentai.club",180],["3gaytube.com",180],["3prn.com",[180,254]],["3xamatorszex.hu",180],["3xfaktor.hu",180],["4archive.org",180],["4fans.gay",180],["4porn4.com",180],["560pmovie.com",180],["69games.xxx",180],["6indianporn.com",180],["7mmtv.sx",180],["85tube.com",180],["8muses.xxx",180],["a-hentai.tv",180],["aagmaal.com",180],["aav.digital",180],["ablefast.com",180],["adltc.cc",180],["adultoffline.com",180],["adultporn.com.es",180],["aflamsexnek.com",180],["ahri8.*",180],["akatsuki-no-yona.com",180],["akutsu-san.com",180],["al4a.com",180],["allafricangirls.net",180],["allcelebs.club",180],["allporncartoons.com",180],["allpussynow.com",180],["allteensnude.net",180],["allureamateurs.net",180],["alotporn.com",180],["amateur-mature.net",180],["amateurandreal.com",180],["amateurbeachspy.com",180],["amateurfapper.com",180],["amateurfun.net",180],["amateurporn.co",180],["amazingtrannies.com",180],["animecast.net",180],["animeidhentai.com",180],["animekage.net",180],["animesex.me",180],["animetoast.cc",180],["annoncesescorts.com",180],["anusling.info",180],["anybunny.com",180],["anynude.net",180],["aoashimanga.com",180],["arabxd.com",180],["arabxforum.com",180],["arabxnx.com",180],["asiaflix.net",180],["asianpornfilms.com",180],["asianpornphoto.net",180],["asianstubefuck.com",180],["asianteenagefucking.com",180],["asiaon.*",[180,270]],["asiaontop.com",[180,270]],["assesphoto.com",180],["axporn.com",180],["azmen.com",180],["b4watch.com",180],["babesexpress.com",180],["babesvagina.com",180],["babesxworld.com",180],["banglachoti-story.com",180],["bangx.org",180],["bbw.com.es",180],["bbw6.com",180],["bbwfest.com",180],["bbwfuckpic.com",180],["bcmanga.com",180],["bdsm-fuck.com",180],["bdsm-photos.com",180],["bdsmstreak.com",180],["beegsexxx.com",180],["beemtube.com",180],["beginningmanga.com",180],["belloporno.com",180],["best18teens.com",180],["bestblackgay.com",180],["bestcam.tv",180],["bestgrannies.com",180],["bestlist.top",180],["bestpornflix.com",180],["bestpussypics.net",180],["bestsextoons.com",180],["bestshemaleclips.com",180],["bigboobs.com.es",180],["bigwank.com",180],["birdurls.com",[180,256]],["bjhub.me",180],["black-matures.com",180],["black-porn-pics.org",180],["blackamateursnaked.com",180],["blackchubbymovies.com",180],["blackcunts.org",[180,320]],["blackedtube.com",180],["blackmaturevideos.com",180],["blackpornhq.com",180],["blacksexmix.com",180],["blackteen.link",180],["blowjobamateur.net",180],["bluetv.xyz",180],["bobolike.com",180],["bokepxv.com",180],["bolly-tube.com",180],["bollywoodx.org",180],["boobs-mania.com",180],["boolwowgirls.com",180],["booru.eu",180],["bootyexpo.net",180],["borwap.xxx",180],["boxporn.net",180],["boystube.link",180],["brazzersbabes.com",180],["bucetaspeludas.com.br",180],["bunkr.*",[180,252]],["bunkrr.*",[180,270]],["buondua.com",180],["bustmonkey.com",180],["bustyfats.com",180],["bustyshemaleporn.com",180],["caitlin.top",180],["callofnight.com",180],["camcam.cc",180],["camgreat.com",180],["cartoonporncomics.info",180],["cartoonvideos247.com",180],["cat3movie.org",180],["cbt-tube.net",180],["cdimg.blog.2nt.com",180],["celebrityleakednudes.com",180],["celebritynakeds.com",180],["celebsnudeworld.com",180],["celebwhore.com",180],["centralboyssp.com.br",180],["cerdas.com",180],["cervezaporno.com",180],["cfake.com",180],["chicasdesnudas.xxx",180],["chopris.com",180],["chubbyelders.com",180],["chubbypornmpegs.com",180],["cine-calidad.*",180],["classicxmovies.com",180],["clicporn.com",180],["clothing-mania.com",180],["comicsarmy.com",180],["comicsporno.xxx",180],["comicspornos.com",180],["comicspornoxxx.com",180],["comicsvalley.com",180],["comicsxxxgratis.com",180],["comicxxx.eu",180],["crazyporn.xxx",180],["crockotube.com",180],["crossdresserhub.com",180],["csrevo.com",180],["cuckold.it",180],["cutiecomics.com",180],["czechsex.net",180],["czechvideo.org",180],["daftporn.com",180],["daftsex.net",180],["daftsex.org",180],["dailyjav.co",180],["danmachimanga.com",180],["darknessporn.com",180],["dataporn.pro",180],["debridup.com",180],["deepfucks.com",180],["deepthroat-porn.com",180],["depvailon.com",180],["descargaranimes.com",180],["desihoes.com",180],["desijugar.net",180],["desimms.co",180],["digitalbeautybabes.com",180],["dikgames.com",180],["dirtybadger.com",180],["dirtyfox.net",180],["dirtygangbangs.com",180],["dirtytamil.com",180],["dlgal.com",180],["dlouha-videa.cz",180],["domahatv.com",180],["domahi.net",180],["donna-cerca-uomo.com",180],["dorohedoro.online",180],["doujindesu.*",[180,215]],["douxporno.com",180],["drsnysvet.cz",180],["dumpz.net",180],["eahentai.com",180],["ebonyamateurphoto.com",180],["ebonyassclips.com",180],["ebuxxx.net",180],["ehotpics.com",180],["epornstore.com",180],["ero18.cc",180],["eroasmr.com",180],["eroclips.org",180],["erogarga.com",180],["erotichun.com",180],["erotichunter.com",180],["eroticmv.com",180],["eroticteensphoto.net",180],["eroxxx.us",180],["escort-in-italia.com",180],["escortconrecensione.com",180],["eshentai.tv",180],["everysextube.com",180],["ex-foary.com",180],["eztvtorrent.co",180],["familyporner.com",180],["famosas-desnudas.org",180],["famousnipple.com",180],["fap16.net",180],["fapcat.com",180],["fapdrop.com",180],["fapset.com",180],["faptube.com",180],["fapxl.com",180],["fatblackmatures.com",180],["fattubevideos.net",180],["fatwhitebutt.com",180],["fatxxxtube.com",180],["felizporno.com",180],["femdomworld.com",180],["femjoybabes.com",180],["fetish-bb.com",180],["fetish-tv.com",180],["fetishburg.com",180],["ffjav.com",180],["fikfok.net",180],["film1k.com",180],["filmpertutti.*",180],["filmpornoitaliano.org",180],["filmyporno.tv",180],["finderporn.com",[180,320]],["finding-camellia.com",180],["findtranny.com",180],["finevids.xxx",180],["folgenporno.com",180],["footfetishvid.com",180],["free-gay-clips.com",180],["free-trannyporn.com",180],["freefatpornmovies.com",180],["freegayporn.me",180],["freegrannypornmovies.com",180],["freehdvideos.xxx",180],["freepdfcomic.com",180],["freepornhdonlinegay.com",180],["freepornjpg.com",180],["freepublicporn.com",180],["freesex-1.com",180],["freexxxvideos.pro",180],["freshscat.com",180],["freshshemaleporn.com",180],["frprn.com",180],["ftopx.com",180],["fuckingsession.com",180],["fuckmilf.net",180],["fucktube4k.com",180],["fuxnxx.com",180],["gatasdatv.com",180],["gay-streaming.com",180],["gay-tubes.cc",180],["gay4porn.com",180],["gayboyshd.com",180],["gayboystube.top",180],["gayfor.us",180],["gayforfans.com",180],["gaypornhdfree.com",180],["gaypornhot.com",180],["gaypornlove.net",180],["gaystream.pw",180],["gayteam.club",180],["gayvideo.me",180],["gayxxxtube.net",180],["gekkouscans.com.br",180],["gelbooru.com",180],["ggbases.com",180],["ghettopearls.com",180],["gifcandy.net",180],["girlfriendsexphoto.com",180],["girlfuckgalleries.com",180],["girlnude.link",180],["glavmatures.com",180],["gonewild.co",180],["good-babes.com",180],["goodporn.to",180],["goshow.tv",180],["gotporn.com",180],["gotxx.*",180],["grannyxxxtube.net",180],["gravuregirlz.com",180],["greatestshemales.com",180],["greatnass.com",180],["greensmut.com",180],["grigtube.com",180],["hachiraw.net",180],["haho.moe",180],["hanime.space",180],["hanimesubth.com",180],["hardfacefuck.com",180],["hcbdsm.com",180],["hd-xxx.me",180],["hdgayporn.net",180],["hdjavonline.com",180],["hdpicsx.com",180],["hdporn-movies.com",180],["hdpornzap.com",180],["hdtubesex.net",180],["hentai-cosplays.com",180],["hentai-for.net",180],["hentai-hot.com",180],["hentai-senpai.*",180],["hentai.tv",180],["hentai20.com",180],["hentai20.io",180],["hentai3z.com",180],["hentaiarena.com",180],["hentaiasmr.moe",180],["hentaibrasil.info",180],["hentaibros.com",180],["hentaicity.com",180],["hentaicore.org",180],["hentaidays.com",180],["hentaienglish.com",180],["hentaihaven.com",180],["hentaihaven.red",180],["hentaihd.xyz",180],["hentaila.com",180],["hentaila.tv",180],["hentaipins.com",[180,312]],["hentaiporno.xxx",180],["hentairead.com",180],["hentaisenpai.*",180],["hentaiteca.net",180],["hentaitk.net",180],["hentaitube1.lol",180],["hentaiworld.tv",180],["hentaiyes.com",180],["herexxx.com",180],["heroine-xxx.com",180],["hindilinks4u.*",[180,255]],["hiperdex.com",180],["hit-erotic.com",180],["hitprn.com",180],["hmanga.asia",180],["ho6ho.com",180],["holaporno.xxx",180],["hoporno.net",180],["hornbunny.com",180],["hornyfanz.com",180],["hotgirl.biz",180],["hotgirlhub.com",180],["hotleak.vip",180],["hotleaks.tv",180],["hotmarathistories.com",180],["hotmaturegirlfriends.com",180],["hotmirrorpics.com",180],["hotntubes.com",180],["hotsexstory.xyz",180],["hotshag.com",180],["house.porn",180],["hqpornero.com",180],["hqpornstream.com",180],["huyamba.*",180],["ibbs.pro",180],["ibecamethewifeofthemalelead.com",180],["ibradome.com",180],["iceporn.tv",180],["ideal-teens.com",180],["ilikecomix.com",180],["imagetwist.netlify.app",180],["imgflare.com",180],["in91vip.win",180],["incontri-in-italia.com",180],["indiansexbazar.com",180],["indianxxx.us",180],["influencersgonewild.com",180],["ingyenszexvideok.hu",180],["iporntoo.com",180],["iusedtobeaboss.com",180],["j-pussy.com",180],["j91.asia",180],["japaneseasmr.com",180],["japanfuck.com.es",180],["japantaboo.com",180],["japanxxxmovie.com",180],["japteenx.com",180],["jasmr.net",180],["jav-torrent.org",180],["jav-xx.com",180],["jav.one",180],["jav101.online",180],["jav380.com",180],["javbake.com",180],["javball.com",180],["javbee.vip",180],["javbest.xyz",180],["javbix.com",180],["javbob.co",180],["javboys.tv",180],["javbull.tv",180],["javcensored.net",180],["javcl.com",180],["javdoge.com",180],["javfav.com",180],["javfullmovie.com",180],["javfun.me",180],["javgay.com",180],["javgrab.com",180],["javhd.*",180],["javheroine.com",180],["javhoho.com",180],["javhun.com",180],["javjavhd.com",180],["javmelon.com",180],["javmilf.xyz",180],["javmobile.net",180],["javmoviexxx.com",180],["javneon.tv",180],["javnew.net",[180,216]],["javopen.co",180],["javpan.net",180],["javpool.com",180],["javporn.tv",180],["javpornfull.com",180],["javprime.net",180],["javpro.cc",180],["javrave.club",180],["javraveclub.com",180],["javring.com",180],["javrip.net",180],["javroi.com",180],["javsaga.ninja",180],["javsex.guru",180],["javsexfree.com",180],["javstor.com",180],["javstream.com",180],["javsub-english.top",180],["javtsunami.com",180],["javtv.to",180],["javuncensored.watch",180],["javxxxporn.com",180],["jizz.us",180],["jotea.cl",180],["jojolandsmanga.com",180],["jpeg.pet",180],["jpg.fishing",180],["jpg2.su",180],["jpvhub.com",180],["juicy3dsex.com",180],["jujmanga.com",180],["jujustu-kaisen.com",180],["justsexpictures.com",180],["kaoskrew.org",180],["kenzato.uk",180],["kiaporn.com",180],["kill-the-hero.com",180],["kissjav.*",[180,252]],["klikmanga.com",180],["klmanga.*",[180,270]],["komikstation.com",180],["komisanwamanga.com",180],["krx18.com",180],["kubo-san.com",180],["kvador.com",180],["latino69.fun",180],["latinohentai.com",[180,368]],["ldkmanga.com",180],["leakedzone.com",180],["leaktube.net",180],["lesbiansex.best",180],["lesbiantube.club",180],["lesboluvin.com",180],["lewdstars.com",180],["lewdweb.net",180],["likuoo.video",180],["ljcam.net",180],["lnk2.cc",180],["longporn.xyz",180],["lovelynudez.com",180],["lulu.st",[180,244,252]],["luscious.net",180],["lustteens.net",180],["m.sextvx.com",180],["madouqu.com",180],["mainporno.com",180],["mamochki.info",180],["manga-dbs.com",180],["manga-scantrad.*",180],["manga18.club",180],["manga18fx.com",180],["mangadass.com",180],["mangadna.com",[180,256]],["mangaforfree.com",180],["mangahatachi.com",180],["mangahub.io",[180,256]],["mangakio.com",180],["mangaonline.fun",180],["mangarawjp.asia",180],["mangarussia.com",180],["manhwa18.cc",180],["manhwaread.com",180],["manhwas.*",180],["manhwaus.net",180],["manyakan.com",180],["mature-tube.sexy",180],["mature4.net",180],["maturepornjungle.com",180],["maturepornphoto.com",180],["maturexxxclips.com",180],["maxjizztube.com",180],["maxtubeporn.net",180],["mdtaiwan.com",180],["meetdownload.com",180],["meetimgz.com",180],["megadede.*",180],["megapornfreehd.com",180],["mespornogratis.com",180],["micmicidol.*",180],["migliori-escort.com",180],["milftoon.xxx",180],["milkporntube.com",180],["mlookalporno.com",180],["mobifuq.com",180],["mobileporn.cam",180],["mom-pussy.com",180],["mommy-pussy.com",180],["mommyporntube.com",180],["momspost.com",180],["momtubeporn.xxx",180],["momxxx.video",180],["momzr.com",180],["moregirls.org",180],["movies18.net",180],["mp4-porn.net",180],["mrjav.net",180],["mrpeepers.net",180],["muchfap.com",180],["multporn.net",180],["musvozimbabwenews.com",180],["mydesibaba.com",180],["mydesiboobs.com",180],["myfreevintageporn.com",180],["mygalls.com",180],["mypornhere.com",[180,349]],["mypornstarbook.net",180],["mypussydischarge.com",180],["myvintageporntube.com",180],["mywatchseries.*",[180,244]],["myxclip.com",180],["myyoungbabe.com",180],["myyouporn.com",180],["nakedamateurs.link",180],["nakedmature.sexy",180],["nangiphotos.com",180],["nanime.us",180],["naughtyza.co.za",180],["needgayporn.com",180],["netfuck.net",180],["nhentai.*",180],["nicheporno.com",180],["nightlifeporn.com",180],["nocfsb.com",180],["novinhassafadinhas.com",180],["novojoy.com",180],["novoporn.com",180],["nsfw247.to",180],["nsfwalbum.com",180],["nude-beach-tube.com",180],["nude-teen-18.com",180],["nudebeachpussy.com",180],["nudeblackgirlfriend.com",180],["nudedxxx.com",180],["nudemomshots.com",180],["nudevista.*",180],["nudismteens.com",180],["nudistic.com",180],["nukedfans.com",180],["nuoga.eu",180],["nyaatorrent.com",180],["ok.xxx",180],["onepiece-manga-online.net",180],["onepiecemangafree.com",180],["onepunch-manga.com",180],["onepunch.*",180],["onlineporno.cc",180],["onlinepornushka.com",180],["onlinesextube.com",180],["onlygangbang.com",180],["onlygayvideo.com",180],["onlyhotleaks.com",180],["onscreens.me",180],["oosex.net",180],["opomanga.com",180],["orgasmatrix.com",180],["otakuraw.net",180],["overhentai.net",180],["palimas.*",180],["parnuhahome.com",180],["pasend.*",180],["pbangels.com",180],["peliculasmx.net",180],["pelisandseries.net",180],["pelispedia.net",180],["penis-milking.com",180],["penisbuyutucum.net",180],["perfektdamen.co",180],["pervertium.com",180],["petitegirlsnude.com",180],["phim85.com",180],["phonerotica.com",180],["pianmanga.*",180],["picmoney.org",180],["picsfuck.org",180],["picspornamateur.com",180],["pictoa.com",180],["pinayviralsexx.com",180],["pinkporno.*",180],["pinsexygirls.com",180],["pisshamster.com",180],["pissingporn.com",180],["pixhost.*",180],["plumpxxxtube.com",180],["plusone8.com",180],["porcore.com",180],["porn-image.net",180],["porn-sexypics.com",180],["porn0.tv",180],["porn0video.com",180],["porn3dx.com",180],["porn720.*",180],["porn77.info",180],["porn78.info",180],["pornabcd.com",180],["pornachi.com",180],["pornbimbo.com",180],["pornchaos.org",180],["pornchimp.com",180],["porncomics.to",180],["porndaa.com",180],["pornditt.com",180],["porndollz.com",180],["porner.tv",180],["pornfuzzy.com",180],["porngayclips.com",180],["porngirlstube.com",180],["porngq.com",180],["porngun.net",180],["pornhat.*",180],["pornhd8k.*",180],["pornhdin.com",180],["pornhegemon.com",180],["pornhex.com",180],["pornhub-teen.com",180],["porninblack.com",180],["pornissimo.org",180],["pornken.com",180],["pornktube.*",180],["pornloupe.com",180],["pornmam.com",180],["pornmom.net",180],["pornmoms.org",180],["pornmonde.com",180],["porno-japones.top",180],["porno-porno.net",180],["porno-rolik.com",180],["pornocolegialas.org",180],["pornocolombiano.net",180],["pornohd.blue",180],["pornoman.pl",180],["pornomanoir.com",180],["pornoperra.com",180],["pornopics.site",180],["pornoreino.com",180],["pornotrack.net",180],["pornpaw.com",180],["pornrabbit.com",180],["pornrewind.com",180],["pornrusskoe.com",180],["pornsai.com",180],["pornsearchengine.com",180],["pornsex-pics.com",180],["pornstargold.com",180],["pornstarsadvice.com",180],["porntin.com",180],["porntrex.pro",180],["porntry.com",180],["pornuj.cz",180],["pornvibe.org",180],["pornwatchers.com",180],["pornxp.org",180],["pornxxxvideos.net",180],["pornyeah.com",180],["pornzone.com",180],["povaddict.com",180],["prothots.com",180],["pulpo69.com",180],["punishworld.com",180],["pussy3dporn.com",180],["pussymaturephoto.com",180],["pvip.gratis",180],["pygodblog.com",180],["qcock.com",180],["queerdiary.com",180],["raccontivietati.com",180],["ragnarokmanga.com",180],["randomarchive.com",180],["rapidzona.tv",180],["rawofficethumbs.com",180],["readfireforce.com",180],["realitybrazzers.com",180],["recordbate.com",180],["redamateurtube.com",180],["reddflix.com",180],["redgay.net",180],["rednowtube.com",180],["redpornnow.com",180],["reifporn.de",180],["repicsx.com",180],["risefromrubble.com",180],["rokuhentai.com",180],["roshy.tv",[180,250]],["rphangx.net",180],["rranime.com",180],["rubias19.com",180],["rule34.art",180],["rule34.paheal.net",180],["rule34porn.net",180],["rushporn.xxx",180],["russkoevideoonline.com",180],["rusteensex.com",180],["saint.to",180],["sankakucomplex.com",180],["santoinferninho.com",180],["saradahentai.com",180],["savelink.site",180],["scallyguy.com",180],["scatkings.com",180],["scatnetwork.com",180],["screenhumor.com",180],["secondcomingofgluttony.com",180],["see-xxx.com",180],["seed69.com",180],["sekaikomik.live",180],["seksrura.net",180],["seksualios.com",180],["seneporno.com",180],["seoul-station-druid.com",180],["seriesyonkis.*",180],["serverxfans.com",180],["sesso-escort.com",180],["severeporn.com",180],["sex-babki.com",180],["sex-pic.info",180],["sex-torrent.net",180],["sexbixbox.com",180],["sexgay18.com",180],["sexkbj.com",180],["sexmutant.com",180],["sexmv.com",180],["sexoverdose.com",180],["sexpornasian.com",180],["sexpox.com",180],["sexpuss.org",180],["sexrura.com",180],["sexrura.pl",180],["sextor.org",180],["sextubefun.com",180],["sextubeset.com",180],["sexvideos.host",180],["sexy-games.*",180],["sexy-parade.com",180],["sexy-youtubers.com",180],["sexyaporno.com",180],["sexyasianteenspics.com",180],["sexybabespictures.com",180],["sexyebonyteen.com",180],["sexyerotica.net",180],["sexyfreepussy.com",180],["sexyhive.com",180],["sexyteengirlfriends.net",180],["shelovesporn.com",180],["shemalemovies.us",180],["shemaletoonsex.com",180],["shlink.net",180],["short.croclix.me",180],["sissytube.net",180],["sitarchive.com",180],["skinnyhq.com",180],["sleazedepot.com",180],["smotret-porno-onlain.com",180],["solomax-levelnewbie.*",180],["solomaxlevelnewbie.*",180],["solopornoitaliani.xxx",180],["somulhergostosa.com",180],["socialmediagirls.com",180],["sousou-no-frieren.*",180],["spy-x-family.*",180],["spycock.com",180],["spyvoyeur.net",180],["stileproject.com",180],["str8ongay.com",180],["stream-69.com",180],["subdivx.com",180],["submissive-wife.net",180],["supremebabes.com",180],["sweetgirl.org",180],["szexvideok.hu",180],["tabooporn.tv",180],["tabooporns.com",180],["tabootube.xxx",180],["tamilsexstory.net",180],["taxi69.com",180],["teenage-nudists.net",180],["teenamateurphoto.com",180],["teenbabe.link",180],["teencamx.com",180],["teenpornjpg.com",180],["teenxxxporn.pro",180],["telugusexkathalu.com",180],["tenseishitaraslimedattaken-manga.com",180],["thaihotmodels.com",180],["thatav.net",180],["thebarchive.com",180],["thebeginningaftertheend.*",180],["thecartoonporntube.com",180],["theeminenceinshadowmanga.com",180],["thehentaiworld.com",180],["thelesbianporn.com",180],["thematurexxx.com",180],["theyarehuge.com",[180,319]],["thothd.com",180],["thotporn.tv",180],["thotsbay.tv",180],["thotslife.com",180],["tioanime.com",180],["titsintops.com",[180,428]],["tittykings.com",180],["tmohentai.com",180],["tojav.net",[180,304]],["tok-thots.com",180],["tokyo-ghoul.online",180],["tokyomotion.com",180],["tokyomotion.net",180],["tokyorevengersmanga.com",180],["tomatespodres.com",180],["tomb-raider-king.com",180],["toon69.com",180],["toonanime.*",180],["topwebgirls.eu",180],["torrent-pirat.com",180],["torture1.net",180],["tpornstars.com",180],["trahino.net",180],["trahodom.com",180],["tranny6.com",180],["trannylibrary.com",180],["trannyline.com",180],["trannysexmpegs.com",180],["trannyxxxtube.net",180],["transexuales.gratis",180],["truyenhentai18.net",180],["ts-mpegs.com",180],["tsmovies.com",180],["tubegaytube.com",180],["tubepornnow.com",180],["tuberzporn.com",180],["tubexo.tv",180],["tuhentaionline.com",180],["turbogvideos.com",180],["turboimagehost.com",180],["twink-hub.com",180],["ulsex.net",180],["ultraten.net",180],["uncensoredleak.com",180],["uniqueten.net",180],["up-load.io",[180,257]],["upicsz.com",180],["upskirt.tv",180],["urgayporn.com",180],["usaxtube.com",180],["vcp.xxx",180],["ver-mangas-porno.com",180],["verhentai.top",180],["vermangasporno.com",180],["verpeliculasporno.gratis",180],["videodotados.com",180],["videos-xxx.*",180],["videosputas.xxx",180],["videosxxxporno.gratis",180],["videosxxxputas.com",180],["viewmature.com",180],["vintageporntubes.com",180],["vipporns.com",180],["viralxvideos.es",180],["vkrovatku.com",180],["voyeurblog.net",180],["voyeurxxxsex.com",180],["vzrosliedamy.com",180],["wannafreeporn.com",180],["wantmature.com",180],["waploaded.com",[180,257]],["watchfreejavonline.co",180],["watchfreekav.com",180],["watchhentai.net",180],["watchporninpublic.com",180],["webcams.casa",180],["webtoonscan.com",180],["westmanga.info",180],["wetpussy.sexy",180],["wetsins.com",180],["womennaked.net",180],["wonporn.com",180],["worldsex.com",180],["wow-mature.com",180],["wowxxxtube.com",180],["x-movie7.com",180],["x-tg.tube",180],["x-video.tube",[180,503]],["x-videos.name",180],["x18.xxx",180],["xanimehub.com",180],["xanimu.com",180],["xasiat.com",180],["xculitos.com",180],["xemales.com",180],["xexle.com",180],["xfantazy.com",180],["xfantazy.org",180],["xforum.live",180],["xfreehd.com",180],["xfreepornsite.com",180],["xhamsterteen.com",180],["xkeezmovies.com",180],["xn--algododoce-j5a.com",180],["xnxx-downloader.net",180],["xnxx.party",180],["xnxxhamster.net",180],["xnxxvideo.pro",180],["xpicse.com",180],["xpornzo.com",180],["xsexpics.com",180],["xspiel.com",180],["xsportshd.com",180],["xszav.club",180],["xvideis.cc",180],["xvideos.name",180],["xvideosxporn.com",180],["xxf.mobi",180],["xxr.mobi",180],["xxu.mobi",180],["xxx-videos.org",180],["xxxcomics.org",180],["xxxfiles.*",180],["xxxhub.cc",180],["xxxputas.net",180],["xxxrip.net",180],["xxxtor.com",180],["xxxxselfie.com",180],["y-porn.com",180],["yaoiscan.com",180],["yona-yethu.co.za",180],["yongfucknaked.com",180],["youlikeboys.com",180],["youngbelle.net",180],["youngerasiangirl.net",180],["youngerporn.mobi",180],["youngleak.com",[180,254]],["youngsexygfs.com",180],["youpornfm.com",180],["youramateurporn.com",180],["yporn.tv",180],["ytanime.tv",[180,258]],["yy1024.net",180],["zonavideosx.com",180],["zthots.com",180],["asiansex.life",180],["javporn18.com",[180,323]],["porntn.com",[180,334]],["blasensex.com",180],["amateurs-fuck.com",180],["sex-amateur-clips.com",180],["dads-banging-teens.com",180],["mature-chicks.com",180],["embedmoon.*",[180,401]],["filemoon.*",[180,400,401]],["hqporner.com",180],["daemon-hentai.com",[180,253]],["cosplay18.pics",180],["pornovka.cz",180],["xmateur.com",180],["mygaytube.com",180],["xnxxcom.xyz",[180,491,492,493]],["freeshot.live",180],["actionviewphotography.com",180],["exporntoons.net",180],["tyler-brown.com",180],["ukdevilz.com",180],["plutomovies.com",180],["adictox.com",180],["japonhentai.com",180],["cambro.io",180],["incgrepacks.com",180],["18adultgames.com",180],["chatropolis.com",180],["angelgals.com",181],["nakedbabes.club",181],["sexybabes.club",181],["cherrynudes.com",181],["hegreartnudes.com",181],["doseofporn.com",181],["secretsdujeu.com",182],["kisstvshow.*",183],["buffstreamz.com",184],["yepi.com",184],["webhostingpost.com",[184,256]],["playmyopinion.com",184],["megagames.com",185],["technews.tw",186],["bluedollar.net",186],["autopareri.com",186],["ffmovies.*",187],["officegamespot.com",188],["parzibyte.me",189],["fotografareindigitale.com",189],["theouterhaven.net",189],["watchallchannels.com",189],["wikipekes.com",189],["androgamer.org",189],["pugam.com",189],["guncelkaynak.com",189],["softwaresblue.com",190],["tapetus.pl",190],["mrpiracy.*",191],["faucetdump.com",192],["dropshipin.id",192],["techtobo.com",192],["jotapov.com",193],["jacksorrell.tv",193],["techilife.com",193],["ligainsider.de",194],["investmentwatchblog.com",195],["insidermonkey.com",195],["fangraphs.com",196],["allcalidad.*",[197,255]],["123anime.*",198],["listenonrepeat.com",199],["xiaomi-miui.gr",200],["photovoltaikforum.com",201],["robot-forum.com",201],["edealinfo.com",201],["soy502.com",202],["vttpi.com",203],["almezoryae.com",203],["arabic-robot.blogspot.com",203],["downloadsoft.net",203],["dafontvn.com",203],["tips97tech.blogspot.com",203],["osxinfo.net",204],["rangerboard.com",204],["bmw-scooters.com",204],["lewdcorner.com",204],["woxmax.net",204],["onlybabes.site",204],["admiregirls.su",204],["kordramass.com",205],["kshowsubindo.org",205],["senimovie.co",205],["orirom.com",206],["romfirmware.com",206],["tatangga.com",206],["evileaks.*",207],["t-rocforum.de",207],["extreme-down.*",[208,209,256]],["tvchoicemagazine.co.uk",210],["hilites.today",210],["modebaca.com",211],["cuatrolatastv.blogspot.com",[212,261]],["pelispedia.*",213],["grid.id",214],["sfmcompile.club",216],["okulsoru.com",217],["onlinetutorium.com",217],["sakaiplus.com",217],["pghk.blogspot.com",217],["bedavapdf.com",217],["minemods.com.br",217],["freshstuff4u.info",217],["anoboy.*",217],["ministryofsolutions.com",217],["xiaomitools.com",217],["depo-program.blogspot.com",217],["texte.work",217],["linksaya.com",217],["moneywar2.blogspot.com",217],["dafideff.com",217],["tutoganga.blogspot.com",217],["link.cgtips.org",217],["gomaainfo.com",217],["acapellas.eu",217],["teknomuda.com",217],["walkthrough-indo.blogspot.com",217],["8tm.net",217],["kayfanet.com",217],["tucsitupdate.blogspot.com",217],["pengantartidurkuh.blogspot.com",217],["whowantstuffs.blogspot.com",217],["decomaniacos.es",217],["copydev.com",217],["masfrandy.com",217],["garaveli.de",217],["rankersadda.in",217],["naijafav.top",217],["ourcoincash.xyz",217],["kiddyshort.com",217],["fellowsfilm.com",218],["netaffiliation.com",219],["spaziogames.it",220],["pg-wuming.com",220],["multics.eu",220],["forexforum.co",220],["tiz-cycling-live.io",221],["tiz-cycling.io",222],["cryptonetos.ru",223],["afreesms.com",223],["ogrenciyegelir.com",224],["iconmonstr.com",224],["theregister.co.uk",225],["wojtekczytawh40k.blogspot.com",226],["pharmaceutical-technology.com",227],["nosteam.ro",227],["duit.cc",228],["labelotaku.com",228],["gsmfirmware.net",228],["rumahit.id",228],["miuiku.com",228],["semuanyabola.com",229],["freeiphone.fr",229],["mobiletrip.net",229],["safemodapk.com",229],["threezly.com",229],["truyenbanquyen.com",229],["veganinja.hu",229],["wikirise.com",229],["mobitool.net",229],["gamingvital.com",229],["dev2qa.com",229],["investnewsbrazil.com",230],["hentaipornpics.net",231],["2kspecialist.net",232],["kutubistan.blogspot.com",232],["softdroid4u.blogspot.com",232],["gbadamud.blogspot.com",232],["rppk13baru.blogspot.com",232],["arabamob.blogspot.com",232],["teachersguidetn.blogspot.com",232],["bayaningfilipino.blogspot.com",232],["akwam.*",[232,258]],["course-downloader.com",232],["digit77.com",233],["gudangfirmwere.com",234],["torresette.news",235],["tryvaga.com",235],["myshopify.com",235],["epainfo.pl",235],["linkvertise.com",[236,237,238]],["wenxuecity.com",238],["mdn.lol",239],["crypto4yu.com",242],["manofadan.com",242],["readbitcoin.org",242],["set.seturl.in",243],["tpi.li",244],["oii.la",244],["stfly.biz",244],["airevue.net",244],["atravan.net",244],["10hitmovies.com",244],["1flix.to",244],["1tamilprint.art",244],["2tamilprint.pro",244],["2024tv.ru",244],["7hitmovies.*",[244,257]],["9animetv.to",244],["9xmoovies.com",244],["advertisertape.com",244],["alldownplay.xyz",244],["alphatron.tv",244],["andyday.*",244],["anime3rb.com",244],["animenexus.in",244],["animeunity.*",244],["animeyabu.org",244],["anisaga.org",244],["anitube.*",244],["aniwatchtv.to",244],["aparttent.com",244],["apkship.shop",244],["arc018.to",244],["ask4movie.*",244],["ate60vs7zcjhsjo5qgv8.com",244],["avjosa.com",244],["bigwarp.io",244],["braflix.tube",244],["capo4play.com",244],["caq21harderv991gpluralplay.xyz",244],["checklinks.online",244],["cinedokan.top",244],["cloudnestra.com",244],["cookiewebplay.xyz",244],["crackstreamsfree.com",244],["daddylive1.ru",244],["databasegdriveplayer.*",244],["dlolcast.pro",244],["dramanice.video",244],["dudefilms.*",244],["ebook-hunter.org",244],["edgedeliverynetwork.com",244],["embasic.pro",244],["embdproxy.xyz",244],["engstreams.shop",244],["enorme.tv",244],["fastdokan.*",244],["fastdownload.top",244],["filecrypt.co",244],["filmyworlds.*",244],["filmyzilla5.com",244],["flixhd.cc",244],["fmoviesto.cc",244],["fojik.*",244],["footballstreams.lol",244],["foreverquote.xyz",244],["frembed.*",[244,250]],["freshwaterdell.com",244],["fsportshd.net",244],["futemais.net",244],["gdflix.*",244],["gdriveplayer.*",244],["gidplayer.online",244],["giize.com",244],["hdfilme.*",[244,258]],["hdstream.one",244],["hakunamatata5.org",244],["hdtodayz.to",244],["hoca2.com",244],["hoca4u.xyz",244],["hollymoviehd.cc",244],["hunterscomics.com",244],["joyousplay.xyz",244],["kaa.mx",244],["kingstreamz.site",244],["lato.sx",244],["likemanga.ink",244],["linkmake.in",244],["lulustream.com",[244,252]],["luluvdoo.com",[244,270,272]],["medeberiya.site",244],["messitv.org",244],["mlbb.space",244],["movieku.ink",244],["moviesapi.to",[244,272]],["movieshdwatch.to",244],["movieshubweb.com",244],["myflixerz.to",244],["nbabite.to",244],["nexdrive.*",244],["neymartv.net",[244,257]],["nflbite.to",244],["nmac.to",244],["ogoplayer.xyz",244],["pelisflix2.*",244],["pkembed.*",244],["player.smashy.stream",[244,471]],["pahe.*",244],["poscitechs.lol",244],["pressplay.cam",244],["pressplay.top",244],["reddit-streams.online",244],["riedberg.tv",244],["ripplestream4u.*",244],["rojadirectaenhd.net",244],["rojadirectaenvivo.la",244],["rubyvid.com",[244,270]],["s2watch.link",244],["savefiles.com",[244,270]],["sflix.*",244],["shazysport.pro",244],["shopr.tv",244],["showflix.*",244],["skysetx.*",244],["snowmtl.ru",244],["soccerstreams.best",244],["souq-design.com",244],["spcdn.xyz",244],["sportingsurge.com",244],["sportsgames.today",244],["sportshub.stream",244],["sportsloverz.xyz",244],["sportsurge.best",244],["sportzlive.shop",244],["spotifylists.com",244],["storynavigation.com",244],["strcloud.in",244],["streamblasters.*",244],["streambtw.com",[244,523]],["streamed.su",244],["streamingunity.to",244],["streamlivetv.site",244],["streamlord.com",244],["streamruby.com",[244,270]],["streamta.site",244],["subtitlecat.com",244],["swfr.tv",244],["tamilprint29.*",244],["tamilprint31.*",244],["tamilprint33.art",244],["tarjetarojaenvivo.lat",244],["telepisodes.org",244],["thedaddy.to",244],["thehesgoal.com",244],["toonstream.*",244],["topembed.pw",244],["tous-sports.ru",244],["tvableon.me",244],["tvsportslive.fr",244],["updown.cam",244],["uqload.*",244],["vegamovies4u.*",244],["video-seed.xyz",244],["videograbber.cc",244],["vinovo.to",[244,406]],["vodkapr3mium.com",244],["watch.ug",244],["watch32.sx",244],["watchadsontape.com",244],["watchf1full.com",244],["watchonlinemovies.vercel.app",244],["watchug.to",244],["wdpglobal.com",244],["weakstreams.online",244],["wmovies.xyz",244],["worldstreamz.shop",244],["xcloud.*",244],["ythd.org",244],["yuppow.com",244],["reliabletv.me",244],["ssyou.tube",244],["y2meta-uk.com",244],["mega4upload.net",244],["livecamrips.su>>",244],["filemoon.*>>",244],["96ar.com>>",244],["designparty.sx>>",244],["iqksisgw.xyz>>",244],["u6lyxl0w.skin>>",244],["ww9g.com>>",244],["nptsr.live>>",244],["4bct9.live>>",244],["xztgl.com>>",244],["remilf.xyz>>",244],["filehost9.com>>",244],["ilovetoplay.xyz",244],["quest4play.xyz",244],["streamcaster.live",244],["weblivehdplay.ru",244],["crichd-player.top",244],["crichdplays.ru",244],["lolcalhost.ru",244],["playtube.tv",244],["tutlehd5.com",244],["filmyfly.*",244],["playeriframe.lol>>",244],["0ochi8hp.com",244],["animefire.info",244],["animesonlinecc.us",244],["animesonliner4.com",244],["animesup.info",244],["animeyabu.net",244],["anitube.us",244],["anitube.vip",244],["caroloportunidades.com.br",244],["dattebayo-br.com",244],["drstonebr.com",244],["file4go.com",244],["flyanimes.cloud",244],["goanimes.vip",244],["goyabu.us",244],["hinatasoul.com",244],["isekaibrasil.com",244],["meuanime.info",244],["otakuanimess.net",244],["superanimes.in",244],["anroll.net",244],["fbstreams.*",244],["bflix.*>>",244],["daddylive.*>>",244],["forgee.xyz",244],["gamehub.cam",244],["watchserieshd.stream>>",244],["freestreams-live.*>>",244],["compu-pc.com",245],["nxprime.in",246],["theuser.cloud",247],["txxx.*",248],["vxxx.com",249],["pornhits.com",249],["mapple.tv",250],["streambucket.net",[250,470]],["gaygo.tv",251],["bunkr-albums.io",252],["saint2.cr",252],["mitaku.net",252],["xmoviesforyou.*",252],["lewdzone.com",252],["activevoyeur.com",254],["allbbwtube.com",254],["alltstube.com",254],["cockmeter.com",254],["18-teen-sex.com",254],["18-teen-tube.com",254],["18girlssex.com",254],["18teen-tube.com",254],["18tubehd.com",254],["2017tube.com",254],["sexmoza.com",254],["yogranny.com",254],["youfreepornotube.com",254],["zhlednito.cz",254],["1movietv.com",255],["33sk.*",255],["3sk.*",255],["4shared.com",255],["anime-odcinki.pl",255],["animesvision.*",255],["bdcraft.net",255],["best4hack.blogspot.com",255],["biqle.com",255],["bmovie.*",255],["cinedetodo.*",255],["cinetux.*",255],["descargas2020.*",255],["extrafreetv.com",255],["exyi.net",255],["filmeonlinehd.biz",255],["fmovie.*",255],["hitokin.net",255],["ipaste.pw",255],["iptvdroid1.blogspot.com",255],["ironysub.*",255],["janjua.*",255],["kstreaming.*",255],["langitmovie.com",255],["libertyvf.*",255],["movieloversworld.com",255],["nensaysubs.net",255],["nflbite.com",255],["onlystream.tv",255],["popcornstream.*",255],["protect-mylinks.com",255],["saveshared.com",255],["shorten.*",255],["solarmovie.*",255],["storieswatch.com",255],["streamango.*",255],["streaming-one.com",255],["streamloverx.com",255],["turkanime.*",255],["uploadev.*",255],["ur-files.com",255],["vidoza.net",255],["vidshare.tv",255],["watchtrailerparkboys.com",255],["xmovies08.*",255],["1111fullwise.*",256],["111watcho.*",256],["123-movies.*",256],["123moviesc.*",256],["123moviesla.*",256],["1kmovies.*",256],["2gomovies.*",256],["4filmyzilla.*",256],["69hoshudaana.*",256],["adshort.*",256],["airportseirosafar.com",256],["ajkalerbarta.com",[256,257]],["akmcloud.*",256],["allmovieshub.*",256],["altadefinizione01.*",[256,257]],["animetak.*",256],["animeworld.tv",256],["appsfree4u.com",[256,257]],["appvn.com",256],["arenavision.*",256],["askim-bg.com",256],["attvideo.com",256],["b-bmovies.com",256],["baixedetudo.net.br",256],["baramjak.com",256],["batmanstream.*",256],["bclikeqt.com",256],["beastlyprints.com",[256,257]],["bengalisite.com",[256,257]],["bollymovies.*",256],["bollywoodfilma.*",256],["buffstream.*",256],["ch-play.com",[256,257]],["charexempire.com",256],["clampschoolholic.*",256],["comandotorrenthd.org",256],["comofuncionaque.com",256],["crackevil.com",[256,339]],["crichd.*",256],["crictime.*",256],["cryptoforu.org",256],["deportealdia.live",256],["dflinks.*",256],["downloadming.*",256],["dramacool.*",256],["e123movies.com",256],["eio.io",256],["essaysharkwriting.club",256],["europix.*",256],["exe.app",256],["exee.io",256],["f1stream.*",[256,257,258]],["fbstream.*",[256,257,258]],["fffmovies.*",256],["filme-bune.biz",256],["filmisongs.*",256],["filmovi.ws",256],["flixhq.ru",256],["flixtor.video",256],["foumovies.*",256],["fullcinema.*",256],["fullreal.*",256],["fulltube.*",256],["fzmoviesnet.com",256],["getmega.net",256],["givemenbastreams.com",256],["givemeredditstreams.com",256],["gnula.*",256],["gogoplay.*",256],["gomo.to",256],["gyonlineng.com",256],["hd44.net",256],["hdmoviehubs.*",256],["hdmovies23.com",256],["hdonline.co",256],["hdpopcorns.*",256],["hdss-to.*",256],["hdzone.org",256],["healthnewsreel.com",[256,257]],["i123movies.net",256],["iegybest.co",256],["ikindlebooks.com",256],["illink.net",256],["imagetot.com",256],["isaimini.ca",256],["iv-soft.com",[256,257]],["jalshamoviezhd.*",256],["janjua.tv",256],["jewelry.com.my",[256,257]],["jkanime.*",256],["johnwardflighttraining.com",[256,257]],["kabarportal.com",[256,257]],["katflys.com",256],["keepv.id",256],["keepvid.*",256],["kiss-anime.*",256],["kissanime.*",[256,259]],["kissasians.org",256],["kissmanga.*",256],["kora-online.tv",256],["kstorymedia.com",[256,257]],["kumascans.com",256],["la123movies.org",256],["leet365.cc",[256,257]],["lespassionsdechinouk.com",[256,257]],["libertestreamvf.*",[256,257]],["linkshere.*",256],["linksmore.*",256],["live7v.com",256],["livestreamtv.pk",[256,257]],["lodynet.*",256],["lookmovie.*",256],["lookmovie186.*",256],["lookmoviess.com",256],["losmovies.*",256],["manga4life.com",256],["mangasco.com",256],["mangceh.cc",256],["masengwa.com",256],["mcdlpit.com",256],["mega-mkv.com",256],["mega-p2p.net",256],["megafilmeshd20.*",256],["megashare-website.com",256],["mettablog.com",256],["mlbstream.*",[256,257,258]],["momomesh.tv",256],["motive213link.blogspot.com",256],["motogpstream.*",[256,257,258]],["moviebb.net",256],["movierulzhd.*",[256,329]],["movies7.to",256],["moviesbaba.*",256],["moviescounter.*",256],["mp3-gratis.it",256],["mp3juice.info",256],["mp3spy.cc",256],["myegy.*",256],["myfernweh.com",[256,257]],["naasongs.*",256],["naasongsfree.*",256],["nbastream.*",[256,257,258]],["nflstream.*",[256,257,258]],["ngomik.net",[256,257]],["nhlstream.*",[256,257,258]],["nmovies.cc",256],["novamovie.net",256],["novelssites.com",256],["oceanofmovies.*",256],["onlinesubtitrat.com",256],["onlinevideoconverter.*",256],["oploverz.*",[256,475]],["orangeink.pk",[256,257]],["ostreaming.tv",256],["pagalworld.*",256],["peliculontube.net",256],["pelismart.com",256],["pelisstar.com",256],["pirlotv.mx",256],["playerfs.com",256],["playlist-youtu.be",256],["playtamil.*",256],["plylive.*",[256,257]],["primewire.*",256],["projectfreetv2.com",256],["putlocker9.*",256],["putlockers.*",[256,257]],["querofilmehd.*",256],["romfast.com",[256,258]],["rugbystreams.*",[256,257,258]],["sdmoviespoint.*",256],["serijehaha.com",[256,257]],["sharkfish.xyz",256],["shortlinkto.*",256],["simsdom.com",256],["skidrow-games.com",256],["sportstreamtv.*",256],["stream.pkayprek.com",256],["talaba.su",[256,257]],["tamilyogi.best",256],["tamilyogis.*",256],["tatabrada.tv",[256,257]],["tenies-online.*",256],["tgo-tv.co",256],["thelinkbox.*",256],["thesuperdownload.*",256],["thingstomen.com",256],["thripy.com",[256,257]],["tlin.me",256],["tvply.*",[256,257]],["u123movies.com",256],["ufcstream.*",[256,257,258]],["ukmagazinesfree.com",256],["uppit.com",[256,261]],["urdubolo.pk",[256,257]],["usagoals.*",256],["vedbom.*",256],["veryfastdownload.pw",256],["vevioz.com",256],["vidbeem.com",256],["vidbm.com",256],["vidcorn.to",256],["vidembed.*",256],["vidlo.us",256],["vkmp3.*",256],["wat32.tv",256],["watchmovieshd.*",256],["watchserieshd.*",256],["watchseriesstream.com",256],["wawacity.*",256],["wifi4games.com",256],["wildwap.*",256],["wmoviesfree.*",256],["xmovies8.*",256],["xxxwebdlxxx.top",256],["yeshd.net",256],["yesmovies.*",256],["yt1s.com",256],["ytsaver.*",256],["zeidgh.com",256],["ziperto.com",[256,265]],["123movies-official.net",257],["123movies-official.site",257],["123movies.net",257],["123movies4up.*",257],["123moviesme.*",257],["123moviesready.org",257],["123moviesto.club",257],["4stream.*",257],["5xmovies.*",257],["720pstream.*",257],["9tsu.*",257],["9xmovie.*",257],["9xupload.*",257],["allosoccer.com",257],["anavidz.com",257],["anidl.org",257],["animasu.club",257],["anime-sanka.com",257],["anime4up.*",257],["animefreak.*",257],["animehditalia.it",257],["animes.vision",257],["animesanka.*",257],["animesultra.com",257],["animesup.*",257],["apkmody.io",257],["apkshrt.com",257],["asianhdplay.net",257],["asianplay.*",257],["asianwatch.net",257],["atdhe.pro",257],["bakotv.com",257],["bbb.fm",257],["bdmusic23.*",257],["bhplay.me",257],["bx-zone.com",257],["canonprintersdrivers.com",257],["cat-a-cat.net",257],["ccnworldtech.com",257],["cheat.hax4you.net",257],["cima100fm.com",257],["clipconverter.cc",257],["crystal-launcher.pl",257],["distanta.net",257],["dtmaga.com",257],["elevationmap.net",257],["eplayvid.*",257],["fakazagods.com",257],["fastilinks.*",257],["fboxtv.com",257],["fightforthealliance.com",257],["fileguru.net",257],["filma1.*",257],["filma24.*",257],["filmy.*",257],["filmyhit.*",257],["flixtor.*",257],["freeromsdownload.com",257],["g3g.*",257],["gameslay.net",257],["gdplayer.*",257],["gentlewasher.com",257],["gofilmes.*",257],["gogoplay1.com",257],["gogoplay2.com",257],["gogoplay4.com",257],["gomoviz.*",257],["govid.*",257],["gum-gum-stream.com",257],["hds-streaming-hd.com",257],["hds-streaming.*",257],["hentaizm.fun",257],["hhdmovies.*",257],["hikarinoakari.com",257],["hilaryhahn.com",257],["hindimovies.*",257],["hothit.me",257],["hotmasti.*",257],["ilgeniodellostreaming.*",257],["ilinks.in",257],["imgspark.com",257],["insurancebillpayment.net",257],["intereseducation.com",257],["jetanimes.*",257],["joolinks.*",257],["jpscan-vf.com",257],["katlinks.*",257],["katmoviehd4.com",257],["kimoitv.com",257],["kingdomfiles.com",257],["liflix.site",257],["linkotes.com",257],["linksfire.*",257],["linksly.co",257],["lustholic.com",257],["mangahere.today",257],["manganatos.com",257],["manhuascan.*",257],["manhwa68.com",257],["mcubd.host",257],["megafilmeseseriesonline.com",257],["melodelaa.*",257],["messitv.net",257],["mkvcage.*",257],["mkvpapa.*",257],["mobdropro.com",257],["modsfire.com",257],["moonblinkwifi.com",257],["moshahda.net",257],["motive213.com",257],["moviedekho.in",257],["moviefreak.*",257],["moviescounnter.com",257],["moviesdaweb.*",257],["moviesland.*",257],["moviewr.com",257],["mp3-now.com",257],["mp3fromyou.tube",257],["mp3juices.su",257],["mp3yeni.org",257],["mycima.*",257],["myoplay.club",257],["networklovers.com",257],["nkiri.com",257],["novelroom.net",257],["ogario.*",257],["okamimiost.com",257],["ovamusic.com",257],["paidnaija.com",257],["pelismarthd.com",257],["pelismartv.com",257],["pelisplus.uproxy.page",257],["pelispoptv.com",257],["pirate4all.com",257],["plyvdo.*",257],["put-locker.com",257],["putingfilm.com",257],["quiltfusion.com",257],["rawkuma.com",257],["redowlanalytics.com",257],["roms-download.com",257],["roms-hub.com",257],["roms-telecharger.com",257],["serien.cam",257],["serienstream.to",257],["series9.*",257],["sflix.pro",257],["shadowrangers.*",257],["showbizbites.com",257],["shrink.*",257],["shrugemojis.com",257],["southfreak.*",257],["ssrmovies.*",257],["stardima.*",257],["stickerdeals.net",257],["stopstreamtv.net",257],["streambee.to",257],["streamsport.*",257],["t7meel.*",257],["tamilarasan.*",257],["tamilfreemp3songs.*",257],["tamilprint.*",257],["tamilprinthd.*",257],["tcpermaculture.com",257],["techmyntra.net",257],["techsslash.com",257],["thelosmovies.com",257],["thememypc.net",257],["thevideome.com",257],["thewatchseries.live",257],["topflix.*",257],["totallyfuzzy.net",257],["traveldesearch.com",257],["tubidy.*",257],["tudotecno.com",257],["tuktukcinema.co",257],["turkish123.com",257],["tvhay.top",257],["uctnew.com",257],["up-load.one",257],["upload-4ever.com",257],["uploadmx.com",257],["uploadrar.*",257],["uploads.mobi",257],["uptobhai.*",257],["uptoimage.com",257],["upvid.*",257],["uwatchfree.*",257],["vanime.*",[257,260]],["vbox7-mp3.info",257],["vf-film.net",257],["vibehubs.com",257],["vipstand.se",257],["viralitytoday.com",257],["voiranime.stream",257],["warefree01.com",257],["watch4hd.*",257],["watchdoctorwhoonline.com",257],["watchimpracticaljokers.com",257],["watchmovie.*",257],["watchopm.net",257],["watchseriess.net",257],["watchtheofficetv.com",257],["watchtvch.club",257],["web.livecricket.is",257],["webloadedmovie.com",257],["whatshowto.com",257],["wifimovies.net",257],["wintub.com",257],["world4ufree1.*",257],["worldgreynews.com",257],["wupfile.com",257],["y-2mate.com",257],["yomoviesnow.com",257],["yoyofilmeys.*",257],["yseries.tv",257],["yt-convert.com",257],["ytconverter.app",257],["ytmp3cc.net",257],["ytmp4.live",257],["ytmp4converter.com",257],["yugen.to",257],["01234movies.*",258],["1234movies.*",258],["123gostream.*",258],["123moviesgo.*",258],["123moviestoday.net",258],["1link.club",258],["1primewire.com",258],["1stkissmanga.*",258],["1tamilmv.*",[258,350]],["8-ball-magic.com",258],["adcorto.*",258],["adsh.cc",258],["afilmyhouse.blogspot.com",258],["aii.sh",258],["animehay.tv",258],["animeheaven.ru",258],["arnaqueinternet.com",258],["asianload.*",258],["ate9ni.com",258],["bdiptv.*",258],["beammeup.com.au",258],["bitlinks.pw",258],["bollyshare.*",258],["ccurl.net",258],["ceesty.com",258],["cinen9.*",258],["citpekalongan.com",258],["claimcrypto.cc",258],["clkmein.com",258],["cllkme.com",258],["comandotorrentshds.org",258],["corneey.com",258],["crazyblog.in",258],["cuevana3.*",258],["destyy.com",258],["dogecoin.*",258],["dramanice.*",258],["earnload.*",258],["eastream.net",258],["ed-protect.org",258],["fakaza.com",258],["festyy.com",258],["filmesonlinex.*",258],["filmy4wap1.*",258],["filmyone.com",258],["freelitecoin.vip",258],["freeload.*",258],["fzmovies.*",258],["gdirect.*",258],["gestyy.com",258],["gogoanimes.*",258],["gulf-up.com",258],["hd44.com",258],["hdstreamss.club",258],["hindimean.com",258],["hindimoviesonline.*",258],["hostxy.com",258],["iiyoutube.com",258],["inextmovies.*",258],["japscan.ws",258],["linkflash.techipe.info",258],["linkskat.*",258],["liveonscore.tv",258],["mailnesia.com",258],["mangaindo.web.id",258],["mangastream.mobi",258],["mega4up.*",258],["megaup.net",258],["mkvhub.*",258],["movies4me.*",258],["moviesmon.*",258],["moviesshub.*",258],["moviessquad.com",258],["movieston.com",258],["moviesub.is",258],["movizland.*",258],["mozkra.com",258],["mp3cristianos.net",258],["mp3songsdownloadf.blogspot.com",258],["naijahits.com",258],["naijal.com",258],["nbch.com.ar",258],["nowmovies.*",258],["ocnpj.com",258],["octanime.net",258],["openload.*",258],["phc.web.id",258],["plusupload.*",258],["pregledaj.net",258],["primeflix.website",258],["py.md",258],["r2sa.net",258],["racaty.*",258],["readingbd.com",258],["receitasoncaseiras.online",258],["recetas.arrozconleche.info",258],["revivelink.com",258],["rojadirecta.*",258],["rojadirectatv.*",258],["s2dfree.*",258],["seriesflv.*",258],["seriesly.*",258],["seuseriado.*",258],["sh.st",258],["shortpaid.com",258],["stalkface.com",258],["strtapeadblock.*",[258,260]],["summarynetworks.com",258],["supervideo.tv",258],["tajpoint.com",258],["techrecur.com",258],["theismailiusa.org",258],["thekingavatar.com",258],["thenetnaija.co",258],["tny.so",258],["torrentfilmes4k.org",258],["try2link.com",258],["uhdstreams.club",258],["upfiles.*",258],["vdtgr.com",258],["vedshar.com",258],["vidcloudpng.com",258],["vidomo.xyz",258],["vidsaver.net",258],["wildwap.com",258],["worldgirlsportal.com",258],["xmovies.*",258],["xsanime.com",258],["ymovies.*",258],["ymp4.download",258],["youtubeai.com",258],["youtubetoany.com",258],["youwatch.*",258],["zone-annuaire.*",258],["zpaste.net",258],["zplayer.live",258],["0123movies.*",259],["2conv.com",259],["anonymous-links.com",259],["bdupload.*",259],["dl-protect.*",259],["dl-protect1.*",259],["doctor-groups.com",259],["dubhappy.net",259],["egyanime.com",259],["filmesonlinehd1.org",259],["firstonetv.*",259],["flvto.biz",259],["goalup.live",259],["gomovieshub.io",259],["gplinks.co",259],["hdmovieplus.*",259],["hydracdn.*",259],["linkshorts.*",259],["manga-raw.club",259],["mangamanga.*",259],["modapkfile.com",259],["movieshub.*",259],["movs4u.*",259],["multifaucet.org",259],["nbaup.live",259],["o2tvseries.website",259],["pewgame.com",259],["q1-tdsge.com",259],["readm.org",259],["shortearn.*",259],["shrlink.top",259],["shugraithou.com",259],["sports24.*",259],["ustream.*",259],["vexfile.com",259],["vexmovies.*",259],["vidlox.*",259],["voe.sx",259],["watchtvseries.video",259],["yesmovies123.me",259],["yifysubtitles.*",259],["adblockstreamtape.*",260],["adblockstrtape.*",260],["adblockstrtech.*",260],["komikcast.*",260],["mavanimes.*",260],["stape.*",260],["streamadblockplus.*",260],["streamta.*",260],["streamtapeadblock.*",260],["strtape.*",260],["strtpe.*",260],["123moviesonline.*",261],["2embed.*",261],["adblockeronstape.*",261],["brbushare.*",261],["cue-vana.com",261],["direct-cloud.me",261],["driveup.in",261],["filmeseries.*",261],["goved.org",261],["hdmovies2.org",261],["hdmovies50.*",261],["seriezloaded.com.ng",261],["skymovieshd.*",261],["slink.bid",261],["stapewithadblock.*",261],["streamers.watch",261],["upbam.org",261],["uplinkto.*",261],["vadbam.com",261],["vadbom.com",261],["vedbam.*",261],["vidbam.org",261],["vidshar.org",261],["moviesnation.*",262],["egydead.*",263],["arabseed.*",264],["liiivideo.com",264],["seeeed.*",264],["adblockeronstreamtape.*",265],["cloudvideo.tv",265],["cloudvideotv.*",265],["hiphopa.net",265],["torrentmac.net",265],["pepperlive.info",266],["filmywap.*",267],["up4stream.com",269],["ups2up.fun",269],["18comic.vip",270],["18comic-gquu.vip",270],["archivebate.*",270],["cyberdrop.me",270],["fapfappy.com",270],["g-porno.com",270],["g-streaming.com",270],["hhkungfu.*",270],["hitomi.la",270],["jav.direct",270],["javboys.cam",270],["javmix.tv",270],["komikmanhwa.me",270],["lovingsiren.com",270],["manga1001.*",270],["mangarawjp.*",270],["natomanga.com",270],["nelomanga.com",270],["netfapx.com",270],["nsfwyoutube.com",270],["nudogram.com",270],["play.playkrx18.site",270],["streampoi.com",270],["syosetu.*",270],["thefappening.pro",270],["thefappeningblog.com",270],["turbocloud.xyz",270],["turbovid.xyz",270],["xanimeporn.com",270],["xxxfree.watch",270],["jonathansociallike.com",270],["rubystm.com",270],["rubyvidhub.com",270],["stmruby.com",270],["bebasbokep.online",[270,524]],["dmovies.top",271],["123animehub.cc",272],["123animes.ru",272],["actvid.*",272],["boosterx.stream",272],["cataz.to",272],["cineb.rs",272],["demonicscans.org",272],["dopebox.to",272],["flixhq.to",272],["gomovies.sx",272],["gomoviestv.to",272],["himovies.sx",272],["limetorrents.lol",272],["mgeko.cc",272],["moflix-stream.fans",272],["mov18plus.cloud",272],["netmovies.to",272],["torrentdownload.*",[272,307,473]],["torrentdownloads.*",[272,307]],["tukipasti.com",272],["vidfast.pro",272],["zoechip.com",272],["onmsft.com",273],["audiotools.pro",274],["audizine.com",274],["blackenterprise.com",274],["cheatsheet.com",274],["cwtv.com",274],["esportstales.com",274],["forums.hfboards.com",274],["fresnobee.com",274],["hancinema.net",274],["hemmings.com",274],["informazionefiscale.it",274],["magesy.*",274],["magesypro.pro",274],["money.it",274],["motorbiscuit.com",274],["movieweb.com",[274,275]],["omg.blog",274],["pastes.io",274],["thegamer.com",[274,275]],["thenerdstash.com",274],["titantv.com",274],["twinfinite.net",274],["wnd.com",274],["worldpopulationreview.com",274],["wral.com",274],["autonews.com",275],["cnet.com",275],["inc.com",275],["mtv.com",275],["polygon.com",275],["vox.com",275],["androidpolice.com",275],["carbuzz.com",275],["cbr.com",275],["collider.com",275],["dualshockers.com",275],["gamerant.com",275],["howtogeek.com",275],["makeuseof.com",275],["screenrant.com",275],["xda-developers.com",275],["animanch.com",276],["blogmura.com",276],["gamewith.jp",276],["jmty.jp",276],["gruene-zitate.de",276],["motor-talk.de",276],["myforecast.com",276],["nlab.itmedia.co.jp",276],["picks.my",276],["thefreebieguy.com",276],["worldhistory.org",276],["helpnetsecurity.com",277],["techieway.blogspot.com",278],["desktophut.com",279],["getitfree.cn",279],["techably.com",280],["minorpatch.com",281],["wg-gesucht.de",283],["okhatrimaza.*",284],["mirrorace.com",285],["supermarches.ca",287],["punisoku.blogo.jp",288],["smartwebsolutions.org",289],["turkrock.com",289],["taigoforum.de",289],["gtamaxprofit.com",290],["linfoweb.com",291],["cracking.org",[292,293]],["lomcn.org",292],["apkdoze.com",292],["aroratr.club",293],["softwaresde.com",294],["artesacro.org",295],["takimag.com",296],["hollywoodpq.com",297],["youranshare.com",298],["freewatchserialonline.com",299],["heavy-r.com",301],["fshost.me",302],["eddiekidiw.com",303],["hdporn92.com",304],["linuxhint.com",305],["thekitchenmagpie.com",305],["newsiqra.com",306],["proxybit.*",307],["grosnews.com",307],["unblocked.name",307],["sharegdrive.com",307],["uproxy2.biz",307],["br0wsers.com",308],["playsexgames.xxx",309],["cryptowin.io",310],["fappee.com",311],["tophentaicomics.com",312],["erotic-beauties.com",312],["hardsex.cc",312],["sex-movies.biz",312],["sikwap.xyz",312],["tube18.sexy",312],["akuu-sflin.blogspot.com",313],["sexflashgame.org",314],["fssquad.com",315],["filtercams.com",316],["elvocero.com",317],["freepornxxxhd.com",318],["cybermania.ws",321],["okteve.com",322],["zdravenportal.eu",324],["shooshtime.com",325],["bittools.net",326],["imginn.com",327],["finchtechs.com",327],["linkpoi.me",328],["freevstplugins.net",329],["insidertracking.com",330],["forobasketcatala.com",331],["dndsearch.in",332],["chapteria.com",333],["samfw.com",335],["ibooks.to",336],["fantasyfootballgeek.co.uk",336],["mrunblock.*",337],["gifans.com",338],["filmyhitlink.xyz",339],["flightsim.to",[340,341]],["cinemakottaga.*",342],["nudes7.com",342],["wgod.co",343],["tutflix.org",343],["spleaks.org",343],["isgfrm.com",343],["tamilbrahmins.com",343],["milanworld.net",343],["arabincest.com",343],["forum.admiregirls.com",343],["hackingfather.com",343],["archpaper.com",344],["justcastingporn.com",345],["justfamilyporn.com",345],["userload.*",346],["fapnado.*",347],["pclicious.net",348],["dsocker1234.blogspot.com",351],["ceylonssh.com",352],["liveonsat.com",353],["luckydice.net",355],["mytoolz.net",356],["freexcafe.com",358],["wishanimes.com",359],["universalfreecourse.com",360],["studybullet.com",361],["superpsx.com",361],["latest-files.com",362],["chicagobearshq.com",363],["chicagobullshq.com",363],["chicagosportshq.com",363],["cubshq.com",363],["tigernet.com",363],["lootup.me",364],["learnclax.com",365],["newsmondo.it",366],["helpdice.com",367],["techsignin.com",369],["osmanonline.co.uk",370],["sarapbabe.com",371],["lbprate.com",372],["katmoviehd.*",372],["virpe.cc",373],["lover937.net",[373,505]],["pherotruth.com",374],["vtube.to",375],["prepostseo.com",376],["order-order.com",377],["cacfutures.org",378],["comexlive.org",378],["daxfutures.org",378],["dollarindex.org",378],["dowfutures.org",378],["ftsefutures.org",378],["mcxlive.org",378],["nasdaqfutures.org",378],["ncdexlive.org",378],["niftyfutures.org",378],["nikkeifutures.org",378],["sgxnifty.org",378],["spfutures.org",378],["learnmania.org",379],["gamingforecast.com",381],["drawize.com",382],["hindimovies.to",383],["alycia-debnam-carey.com",384],["christinaricci.net",384],["emmy-rossum.com",384],["natalie-portman.org",384],["rachel-brosnahan.org",384],["111.90.150.10",385],["111.90.141.252",385],["entireweb.com",386],["babia.to",387],["racedepartment.com",387],["r3owners.net",387],["hentaimoe.me",388],["111.90.150.149",389],["111.90.151.26",389],["currencyconverterx.com",390],["apkmodhub.in",391],["faucetcrypto.net",392],["valeronevijao.com",393],["cigarlessarefy.com",393],["figeterpiazine.com",393],["yodelswartlike.com",393],["generatesnitrosate.com",393],["crownmakermacaronicism.com",393],["chromotypic.com",393],["gamoneinterrupted.com",393],["metagnathtuggers.com",393],["wolfdyslectic.com",393],["rationalityaloelike.com",393],["sizyreelingly.com",393],["simpulumlamerop.com",393],["urochsunloath.com",393],["monorhinouscassaba.com",393],["counterclockwisejacky.com",393],["35volitantplimsoles5.com",393],["scatch176duplicities.com",393],["antecoxalbobbing1010.com",393],["boonlessbestselling244.com",393],["cyamidpulverulence530.com",393],["guidon40hyporadius9.com",393],["449unceremoniousnasoseptal.com",393],["19turanosephantasia.com",393],["30sensualizeexpression.com",393],["321naturelikefurfuroid.com",393],["745mingiestblissfully.com",393],["greaseball6eventual20.com",393],["toxitabellaeatrebates306.com",393],["20demidistance9elongations.com",393],["audaciousdefaulthouse.com",393],["availedsmallest.com",393],["fittingcentermondaysunday.com",393],["fraudclatterflyingcar.com",393],["launchreliantcleaverriver.com",393],["matriculant401merited.com",393],["realfinanceblogcenter.com",393],["reputationsheriffkennethsand.com",393],["telyn610zoanthropy.com",393],["tubelessceliolymph.com",393],["tummulerviolableness.com",393],["un-block-voe.net",393],["v-o-e-unblock.com",393],["voe-un-block.com",393],["voe-unblock.*",393],["voeun-block.net",393],["voeunbl0ck.com",393],["voeunblck.com",393],["voeunblk.com",393],["voeunblock.com",393],["voeunblock1.com",393],["voeunblock2.com",393],["voeunblock3.com",393],["givee.club",394],["erome.com",395],["missav.*",396],["missav123.com",396],["missav888.com",396],["angelfire.com",397],["erotom.com",398],["moviewatch.com.pk",399],["shesfreaky.com",399],["hentaibatch.com",399],["vrporn.com",400],["1azayf9w.xyz",401],["c4qhk0je.xyz",401],["fmhd.bar",401],["vidsrc.click",401],["filemoon-59t9ep5j.xyz",402],["filemoon-nv2xl8an.xyz",402],["ps2-bios.com",404],["odum.cl",405],["helmiau.com",406],["coolrom.com.au",407],["ksl.com",408],["bang14.com",409],["komputerswiat.pl",410],["tokuvn.com",411],["lover92.net",412],["kpopjams.com",413],["thiepmung.com",414],["rlxtech24h.com",415],["emsnow.com",416],["bagpipe.news",416],["ckxsfm.com",416],["msmorristown.com",416],["durhamopenhouses.com",416],["careersatcouncil.com.au",416],["sexjobs.es",417],["cloudcomputingtopics.com",418],["cloud-computing-central.com",419],["nudostar.com",420],["hentaihaven.vip",421],["nhentaihaven.org",421],["hdrez.com",422],["xhvid1.com",423],["tagecoin.com",[424,425]],["claimsatoshi.xyz",425],["harshfaucet.com",425],["mcafee-com.com",425],["financialjuice.com",427],["n.fcd.su",429],["archiwumalle.pl",431],["gloryshole.com",432],["hentaikai.com",434],["telesrbija.com",435],["nerdiess.com",436],["gledaitv.*",437],["xxxtik.com",438],["imgbox.com",439],["xpornium.net",440],["mangaesp.co",441],["photooxy.com",442],["darksoftware.net",[443,444]],["bunkr.la",445],["lgwebos.com",446],["sociologicamente.it",447],["burbuja.info",448],["aliendictionary.com",449],["proverbmeaning.com",449],["tudongnghia.com",449],["vietnamanswer.com",449],["telorku.xyz",450],["chat.tchatche.com",451],["hentaibooty.com",452],["nicekkk.com",453],["hes-goals.*",454],["av01.media",455],["decorisi.com",456],["expertplay.net",457],["udemy-downloader.com",458],["myvidster.com",459],["ggjav.com",460],["ggjav.tv",460],["ecamrips.com",[461,462]],["showcamrips.com",[461,462]],["cimanow.cc",463],["freex2line.online",463],["whoreshub.com",464],["cryptoclicks.net",465],["sonixgvn.net",466],["paste-drop.com",467],["db-creation.net",468],["imagefap.com",469],["player.smashystream.com",471],["fmovies.*",472],["3upload.com",474],["file-up.org",474],["timesnewsgroup.com.au",475],["mangaku.*",477],["carbonite.co.za",479],["m.akkxs.net",480],["bailiwickexpress.com",481],["tv.bdix.app",482],["deano.me",483],["themehospital.co.uk",483],["resplace.com",483],["daotranslate.*",484],["tainguyenmienphi.com",485],["overtake.gg",486],["ripleyfieldworktracker.com",487],["iggtech.com",488],["asia.5ivttv.vip",488],["matrixserver.in",489],["uiiumovie.*",490],["sport890.com.uy",494],["coomer.su",495],["kemono.su",495],["smithsonianmag.com",496],["pianetalecce.it",497],["decompiler.com",498],["cgcosplay.org",499],["crackshash.com",500],["zone-telechargement.ing",501],["idnes.cz",502],["vidlink.pro",504],["111movies.com",504],["456movie.com",504],["moviedokan.*",506],["fileplanet.com",507],["wvt.free.nf",508],["hotgirlpix.com",509],["mma-core.*",510],["ignboards.com",511],["hentai2w.com",512],["futbolsayfasi.net",513],["netronline.com",514],["moviediskhd.cloud",515],["comdotgame.com",516],["abstream.to",517],["bollydrive.*",518],["gleaks.pro",519],["whoisnovel.com",520],["videezy.com",521],["onlyssh.my.id",522],["whyvpn.my.id",522],["omegascans.org",525],["jav.sb",526],["business-standard.com",527],["uindex.org",528],["indojavstream.com",529],["liberation.fr",530],["officedepot.fr",530],["oui.sncf",530]]);
const exceptionsMap = new Map([["cloudflare.com",[0,244,244]],["oxy.edu",[12,430]],["disqus.com",[244,244]],["google.com",[244,244]],["chatango.com",[244,244]],["twitter.com",[244]],["youtube.com",[244]],["mangaku.win",[477]]]);
const hasEntities = true;
const hasAncestors = true;

const collectArgIndices = (hn, map, out) => {
    let argsIndices = map.get(hn);
    if ( argsIndices === undefined ) { return; }
    if ( typeof argsIndices !== 'number' ) {
        for ( const argsIndex of argsIndices ) {
            out.add(argsIndex);
        }
    } else {
        out.add(argsIndices);
    }
};

const indicesFromHostname = (hostname, suffix = '') => {
    const hnParts = hostname.split('.');
    const hnpartslen = hnParts.length;
    if ( hnpartslen === 0 ) { return; }
    for ( let i = 0; i < hnpartslen; i++ ) {
        const hn = `${hnParts.slice(i).join('.')}${suffix}`;
        collectArgIndices(hn, hostnamesMap, todoIndices);
        collectArgIndices(hn, exceptionsMap, tonotdoIndices);
    }
    if ( hasEntities ) {
        const n = hnpartslen - 1;
        for ( let i = 0; i < n; i++ ) {
            for ( let j = n; j > i; j-- ) {
                const en = `${hnParts.slice(i,j).join('.')}.*${suffix}`;
                collectArgIndices(en, hostnamesMap, todoIndices);
                collectArgIndices(en, exceptionsMap, tonotdoIndices);
            }
        }
    }
};

const entries = (( ) => {
    const docloc = document.location;
    const origins = [ docloc.origin ];
    if ( docloc.ancestorOrigins ) {
        origins.push(...docloc.ancestorOrigins);
    }
    return origins.map((origin, i) => {
        const beg = origin.lastIndexOf('://');
        if ( beg === -1 ) { return; }
        const hn = origin.slice(beg+3)
        const end = hn.indexOf(':');
        return { hn: end === -1 ? hn : hn.slice(0, end), i };
    }).filter(a => a !== undefined);
})();
if ( entries.length === 0 ) { return; }

const todoIndices = new Set();
const tonotdoIndices = new Set();

indicesFromHostname(entries[0].hn);
if ( hasAncestors ) {
    for ( const entry of entries ) {
        if ( entry.i === 0 ) { continue; }
        indicesFromHostname(entry.hn, '>>');
    }
}

// Apply scriplets
for ( const i of todoIndices ) {
    if ( tonotdoIndices.has(i) ) { continue; }
    try { abortCurrentScript(...argsList[i]); }
    catch { }
}

/******************************************************************************/

// End of local scope
})();

void 0;
